// A Bison parser, made by GNU Bison 3.0.4.

// Skeleton implementation for Bison LALR(1) parsers in C++

// Copyright (C) 2002-2015 Free Software Foundation, Inc.

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

// As a special exception, you may create a larger work that contains
// part or all of the Bison parser skeleton and distribute that work
// under terms of your choice, so long as that work isn't itself a
// parser generator using the skeleton or a modified version thereof
// as a parser skeleton.  Alternatively, if you modify or redistribute
// the parser skeleton itself, you may (at your option) remove this
// special exception, which will cause the skeleton and the resulting
// Bison output files to be licensed under the GNU General Public
// License without this special exception.

// This special exception was added by the Free Software Foundation in
// version 2.2 of Bison.
// //                    "%code top" blocks.
#line 44 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:397


#include <iostream>
#include <sstream>
#include <fstream>
#include <cstdlib>
#include <string>
#include <unordered_map>
#include <map>
#include <vector>
#include <complex>

#include <Teuchos_RCP.hpp>

#include "location.hh"
#include "position.hh"
#include <N_ERH_Message.h>
#include <N_IO_fwd.h>
#include <N_UTL_Math.h>
#include "ExpressionType.h"
#include "ast.h"
#include "newExpression.h"


namespace Xyce {
namespace Util {
  
template <typename ScalarT>
class tableArgs
{
  public:
    std::string * keywordPtr;
    Teuchos::RCP<astNode<ScalarT> > node;
};

class ExpressionLexer;
}}


#line 74 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:397

// Take the name prefix into account.
#define yylex   XyceExpressionlex

// First part of user declarations.

#line 81 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:404

# ifndef YY_NULLPTR
#  if defined __cplusplus && 201103L <= __cplusplus
#   define YY_NULLPTR nullptr
#  else
#   define YY_NULLPTR 0
#  endif
# endif

#include "ExpressionParser.hxx"

// User implementation prologue.

#line 95 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:412
// Unqualified %code blocks.
#line 84 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:413

#undef yylex
#include <FlexLexer.h>
#include "ExpressionLexer.h"
#define yylex XyceExpressionlex

int XyceExpressionlex(
    XyceExpression::ExpressionParser::semantic_type *lvalp, 
    XyceExpression::location *locp,
    Xyce::Util::ExpressionLexer *theLexer);
#line 104 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:413



//-------------------------------------------------------------------------
// Function      : checkGroundName
// Purpose       : checks if the name of a voltage node is a synonym for ground
// Special Notes :
// Scope         :
// Creator       : Eric Keiter
// Creation Date : 9/3/2020
//-------------------------------------------------------------------------
bool checkGroundNodeName(std::string & name)
{
  std::string tmpName = name;
  Xyce::Util::toUpper(tmpName);

  if (tmpName == std::string("0")) { return true; }

  if (Xyce::Util::preprocessFilter.size() >= Xyce::IO::PreprocessType::NUM_PREPROCESS)
  {
  if (Xyce::Util::preprocessFilter[Xyce::IO::PreprocessType::REPLACE_GROUND])
  {
    if (tmpName == std::string("GND")) { return true; }
    if (tmpName == std::string("GND!")) { return true; }
    if (tmpName == std::string("GROUND")) { return true; }
  }
  }

  bool thisIsGround=false;
  if (tmpName.size() > 1)
  {
    std::size_t lastColonIndex = tmpName.find_last_of(":");
    std::size_t last = tmpName.size()-1;
    if (lastColonIndex < last)
    {
      std::string endOfName = tmpName.substr(lastColonIndex,last);
      if (endOfName == ":0") { thisIsGround=true; }
      else if (endOfName == ":GND") { thisIsGround=true; }
      else if (endOfName == ":GND!") { thisIsGround=true; }
      else if (endOfName == ":GROUND") { thisIsGround=true; }
    }
  }

  return thisIsGround;
}

//-------------------------------------------------------------------------
// Function      : setupCoords
// Purpose       : Support function for setupPoly, which provides coordinates for a specific term.
//
// Special Notes : 
//
// The coefficients in a POLY statement are specified as an arbitrarily long list of numbers.  
//
// The coefs are listed in the order of polynomial order.  
// So, the coefs for order=0 are first, followed by coefs for order=1, then order=2, etc.
// 
// The number of coefs needed at each order increases exponentially, w.r.t. the number of variables. 
// If the number of variables = N = 2 then the number of coefs for each order is:
// order 0 -> N^0 = 1
// order 1 -> N^1 = N = 2
// order 2 -> N^2 = N*N = 4
// order 3 -> N^3 = N*N*N = 8 
// etc.
//
// This function deals only with the coefs of a specific order, a subset of the original list.
// For that order, it figures out the multi-dimensional indexing needed to properly compute 
// this specific term in the polynomial.
//
// For example, if you are dealing with the 3rd order terms, then 
// each term will have the form:  Cijk * var_i*var_j_*var_k.  This function determins 
// what the values of i,j,k must be, for a given index in the 1D coef array.
//
// If dealing with 3rd order, and 2 inputs, then there will be 8 coefs and their order is:
//     C000 C001 C010 C011 C100 C101 C110 C111
// and their poly terms are:
//
//   C000*X0*X0*X0 + C001*X0*X0*X1 + C010*X0*X1*X0 + C011*X0*X1*X1 + 
//   C100*X1*X0*X0 + C101*X1*X0*X1 + C110*X1*X1*X0 + C111*X1*X1*X1
//
// where "X" are variables
//
// The "localIndex" is the index relative to the beginning of this order of terms.  
// So, in the above example C000 would be localIndex=0, and C001 would be localIndex=1
//
// This function, given the number of variables, the current order, and the localIndex 
// provides the coordinates needed to evaluate the given polynomial term.  
//
// So for example, if N=2 and order=3, and localIndex=4, then this function should 
// populate coords as: coords = {1,0,0}
//
// Scope         :
// Creator       : Eric Keiter
// Creation Date : 1/7/2021
//-------------------------------------------------------------------------
void setupCoords (int order, int localIndex, int numvars, std::vector<int> & coords)
{
  coords.resize(order,0);
  int p=numvars;
  int d=order;
  int indx = localIndex;
  for (int k = d-1; k >= 0; k--) 
  {
    coords[k] = indx % (p);
    indx /= p;
  }
}

//-------------------------------------------------------------------------
// Function      : setupPoly
// Purpose       : Does work to create an expression tree representing the 
//                 POLY operator
//
// Special Notes : Given the following POLY specification:
//
//  POLY(N) X1 ...XN   C0 C1 ...CN   C11 ...C1N    C21 ...CN1 ...CNN    C121 ...C12N ...
//  
// The AST constructed by this function needs to evaluate the following polynomial:
//
// term order: 
//   0         Value = C0 
//   1                   + sum_{j=1}^N C_j X_j 
//   2                   + sum_{i=1}^N sum_{j=1}^N C_{ij} X_i X_j
//   3                   + sum_{i=1}^N sum_{j=1}^N sum_{k=1}^N C_{ijk} X_i * X_j * X_k + ...
//             ....
//
// Scope         :
// Creator       : Eric Keiter
// Creation Date : 1/7/2021
//-------------------------------------------------------------------------
Teuchos::RCP<astNode<usedType> > setupPoly(
    Xyce::Util::newExpression & newExp,
    usedType numvars, 
    std::vector<Teuchos::RCP<astNode<usedType> > > & vars_and_coefs
    )
  {
  int sizeOfVars_ = static_cast<int>(std::real(numvars));

  if (vars_and_coefs.size() <= sizeOfVars_)
  {
    Xyce::Report::UserError()
     << "Not enough arguments in POLY expression:" << newExp.getExpressionString() << std::endl;
  }

  std::vector<Teuchos::RCP<astNode<usedType> > > vars;
  vars.insert(vars.end(),vars_and_coefs.begin(), vars_and_coefs.begin() + sizeOfVars_);
  for(int ii=0;ii<sizeOfVars_;ii++)
  {
    if (vars[ii]->numvalType())
    {
      Xyce::Report::UserError()
       << "There needs to be " << sizeOfVars_ 
       << " input solution variables in POLY expression:" << newExp.getExpressionString() << std::endl;
    }
  }

  std::vector<Teuchos::RCP<astNode<usedType> > > coefs;
  coefs.insert(coefs.end(), vars_and_coefs.begin() + sizeOfVars_, vars_and_coefs.end());

  Teuchos::RCP<astNode<usedType> > tmpPtr;
  Teuchos::RCP<astNode<usedType> > tmpPtr2;
  Teuchos::RCP<astNode<usedType> > value;
  Teuchos::RCP<astNode<usedType> > value2;

  // Set up arrays to determine what range of coefs corresponds to each order.
  int currentOrderSize=1;
  int currentMaxIndex=currentOrderSize;
  std::vector<int> orderMinIndex(1,0);
  std::vector<int> orderMaxIndex(1,currentMaxIndex);
  while(currentMaxIndex < coefs.size())
  {
    currentOrderSize *= vars.size();
    orderMinIndex.push_back(currentMaxIndex);
    currentMaxIndex += currentOrderSize;
    orderMaxIndex.push_back(currentMaxIndex);
  }

  // This creates an AST, with "value" at the head.
  // It loops over all the used orders, and for each order, then loops over the 
  // coefs for that order and uses them to create AST contributions for that 
  // part of the polynomial.
  value = coefs[0];
  int maxOrderPlus1 = orderMaxIndex.size();
  for (int iorder=1;iorder<maxOrderPlus1;iorder++)
  {
    int localIndex=0;
    for(int ii=orderMinIndex[iorder];ii<orderMaxIndex[iorder];++ii,++localIndex) // loop over coefs of the current order
    {
      if(ii>=coefs.size()) break;
  
      tmpPtr = coefs[ii];
      std::vector<int> coords;
      setupCoords(iorder, localIndex, vars.size(), coords); // get the coordinates for this term
      for (int ie=0;ie<coords.size();ie++) 
      {
        tmpPtr2 = Teuchos::RCP<astNode<usedType> >(new binaryMulOp<usedType>  (tmpPtr,vars[coords[ie]]));
        tmpPtr = tmpPtr2;
      }
      value2 = Teuchos::RCP<astNode<usedType> >(new binaryAddOp<usedType>  (value,tmpPtr));
      value = value2;
    }
  }
  return value;
}

//-------------------------------------------------------------------------
// Function      : createParamOp 
// Purpose       : Does work required to allocate parameter operator
// Special Notes : This is a separate function, b/c two rules use it.
// Scope         :
// Creator       : Eric Keiter
// Creation Date : 1/7/2021
//-------------------------------------------------------------------------
void createParamOp(
  Teuchos::RCP<astNode<usedType> > & returnPtr,
    Xyce::Util::newExpression & newExp,
    const std::string &  paramName)
{
  // ensure that each parameter and/or function argument  has a single, unique astNode allocated for it
  //
  // note that maps are not used here, intentionally, so as to preseve the original order of params.
  // using a std::vector for the names and a separate vector for the paramOps keeps them in order user specified.
  std::vector<std::string> & paramNameVec = newExp.getParamNameVec ();
  std::vector<Teuchos::RCP<astNode<usedType> > > & paramOpVec = newExp.getParamOpVec ();
  std::unordered_map<std::string,std::vector<Teuchos::RCP<astNode<usedType> > > > & paramOpMap = newExp.getParamOpMap ();

  //std::vector<std::string>::iterator nameIter = std::find(paramNameVec.begin(),paramNameVec.end(), paramName);
  //if ( nameIter == paramNameVec.end() )
  if ( paramOpMap.find( paramName ) == paramOpMap.end() )
  {
    returnPtr = Teuchos::RCP<astNode<usedType> >(new paramOp<usedType>(paramName));
    paramOpVec.push_back(returnPtr);

    std::vector<Teuchos::RCP<astNode<usedType> > > vec;
    vec.push_back(returnPtr);
    paramOpMap[paramName] = vec;

    paramNameVec.push_back(paramName);
  }
  else
  {
    returnPtr = Teuchos::RCP<astNode<usedType> >(paramOpMap[paramName][0]);
  }
}

//-------------------------------------------------------------------------
// Function      : createVoltageOp
// Purpose       : Does work required by the rules for voltage operators
// Special Notes : This is a separate function, b/c two rules use it.
// Scope         :
// Creator       : Eric Keiter
// Creation Date : 9/3/2020
//-------------------------------------------------------------------------
void createVoltageOp(
  Teuchos::RCP<astNode<usedType> > & returnPtr,
    Xyce::Util::newExpression & newExp,
    const std::string & prefix, const std::vector<std::string> & nodes)
{
  std::vector<std::string> voltageNodes = nodes;
  Teuchos::RCP<astNode<usedType> > tmpPtr;

  std::vector<std::string> & voltNameVec = newExp.getVoltNameVec ();
  std::vector<Teuchos::RCP<astNode<usedType> > > & voltOpVec = newExp.getVoltOpVec();
  std::unordered_map<std::string,std::vector<Teuchos::RCP<astNode<usedType> > > > & voltOpMap = newExp.getLocalVoltOpMap();

  if (voltageNodes.size() == 1)
  {
    if ( !checkGroundNodeName(voltageNodes[0]) )
    {
      // ensure that each voltage has a single, unique astNode allocated for it
      if ( voltOpMap.find( voltageNodes[0] ) == voltOpMap.end() )
      {
        Teuchos::RCP<voltageOp<usedType> > voltPtr = Teuchos::RCP<voltageOp<usedType> >(new voltageOp<usedType>(voltageNodes[0]));
        tmpPtr = Teuchos::RCP<astNode<usedType> >(voltPtr);
        newExp.getVoltOpVec ().push_back(voltPtr);
        voltNameVec.push_back( voltageNodes[0] );

        std::vector<Teuchos::RCP<astNode<usedType> > > vec;
        vec.push_back(voltPtr);
        voltOpMap[ voltageNodes[0] ] = vec;
      }
      else
      {
        tmpPtr = Teuchos::RCP<astNode<usedType> >(voltOpMap[voltageNodes[0]][0]);
      }
    }
    else
    {
      Teuchos::RCP<astNode<usedType> > voltPtr = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(0.0));
      tmpPtr = Teuchos::RCP<astNode<usedType> >(voltPtr);
    }
  }
  // For the nodal difference use case, V(A,B) is handled as follows.
  // Instead of having the voltageOp class handle the differencing, 
  // create two voltage node objects, one for V(A) and one for V(B) and then
  // pass them as arguments to a binaryMinusOp operator.
  else if (voltageNodes.size() == 2) 
  {
    Teuchos::RCP<astNode<usedType> > tmp1Ptr;
    Teuchos::RCP<astNode<usedType> > tmp2Ptr;

    if ( !checkGroundNodeName( voltageNodes[0]) )
    {
      // ensure that each voltage has a single, unique astNode allocated for it
      if ( voltOpMap.find( voltageNodes[0] ) == voltOpMap.end() )
      {
        Teuchos::RCP<voltageOp<usedType> > volt1Ptr = Teuchos::RCP<voltageOp<usedType> >(new voltageOp<usedType>(voltageNodes[0]));
        tmp1Ptr = Teuchos::RCP<astNode<usedType> >(volt1Ptr);
        voltOpVec.push_back(volt1Ptr);
        voltNameVec.push_back( voltageNodes[0] );

        std::vector<Teuchos::RCP<astNode<usedType> > > vec;
        vec.push_back(volt1Ptr);
        voltOpMap[ voltageNodes[0] ] = vec;
      }
      else
      {
        tmp1Ptr = Teuchos::RCP<astNode<usedType> >(voltOpMap[voltageNodes[0]][0]);
      }
    }
    else
    {
      Teuchos::RCP<astNode<usedType> > voltPtr = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(0.0));
      tmp1Ptr = Teuchos::RCP<astNode<usedType> >(voltPtr);
    }

    if ( !checkGroundNodeName( voltageNodes[1]) )
    {
      // ensure that each voltage has a single, unique astNode allocated for it
      if ( voltOpMap.find( voltageNodes[1] ) == voltOpMap.end() )
      {
        Teuchos::RCP<voltageOp<usedType> > volt2Ptr = Teuchos::RCP<voltageOp<usedType> >(new voltageOp<usedType>(voltageNodes[1]));
        tmp2Ptr = Teuchos::RCP<astNode<usedType> >(volt2Ptr);
        voltOpVec.push_back(volt2Ptr);
        voltNameVec.push_back( voltageNodes[1] );

        std::vector<Teuchos::RCP<astNode<usedType> > > vec;
        vec.push_back(volt2Ptr);
        voltOpMap[ voltageNodes[1] ] = vec;
      }
      else
      {
        tmp2Ptr = Teuchos::RCP<astNode<usedType> >(voltOpMap[voltageNodes[1]][0]);
      }
    }
    else
    {
      Teuchos::RCP<astNode<usedType> > voltPtr = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(0.0));
      tmp2Ptr = Teuchos::RCP<astNode<usedType> >(voltPtr);
    }

    tmpPtr = Teuchos::RCP<astNode<usedType> >(new binaryMinusOp<usedType>  (tmp1Ptr,tmp2Ptr));
  }

  // adjust for complex number variants
  // remove whitespace from the first argument
  const std::string & firstArg = (prefix);
  if (firstArg.size() == 1)
  {
    returnPtr = tmpPtr;
  }
  else if (firstArg.size() == 2)
  {
     if ( firstArg == std::string("VR") )
     {
       returnPtr = Teuchos::RCP<astNode<usedType> >(new realOp<usedType>(tmpPtr));
     }
     else if ( firstArg == std::string("VI") )
     {
       returnPtr = Teuchos::RCP<astNode<usedType> >(new imagOp<usedType>(tmpPtr));
     }
     else if ( firstArg == std::string("VM") )
     {
       returnPtr = Teuchos::RCP<astNode<usedType> >(new absOp<usedType>(tmpPtr));
     }
     else if ( firstArg == std::string("VP") )
     {
       returnPtr = Teuchos::RCP<astNode<usedType> >(new phaseOp<usedType>(tmpPtr));
       newExp.getPhaseOpVec().push_back(returnPtr);
     }
  }
  else if (firstArg.size() == 3) // do decibels here
  {
    if ( firstArg == std::string("VDB") )
    {
      // this needs to implement 20.0*std::log10(abs(*tmpPtr))  
      Teuchos::RCP<astNode<usedType> > numvalPtr = Teuchos::RCP<astNode<usedType> >(new numval<usedType> (20.0));
      Teuchos::RCP<astNode<usedType> > absPtr = Teuchos::RCP<astNode<usedType> >(new absOp<usedType>(tmpPtr));
      Teuchos::RCP<astNode<usedType> > log10Ptr = Teuchos::RCP<astNode<usedType> >(new log10Op<usedType>(absPtr));
      returnPtr = Teuchos::RCP<astNode<usedType> >(new binaryMulOp<usedType>  (numvalPtr,log10Ptr));
    }
  }
  else
  {
    std::cout << "Unrecognized voltage operator " << firstArg << std::endl;
  }
}

//-------------------------------------------------------------------------
// Function      : createCurrentOp
// Purpose       : Does work required by the rules for current operators
// Special Notes : This is a separate function, b/c two rules use it.
// Scope         :
// Creator       : Eric Keiter
// Creation Date : 9/3/2020
//-------------------------------------------------------------------------
void createCurrentOp(
    Teuchos::RCP<astNode<usedType> > & returnPtr,
    Xyce::Util::newExpression & newExp,
    const std::string & prefix, const std::string & device)
{
  const std::string & firstArg = prefix;

  std::string deviceName = device; // can't use a non-const reference ...
  std::string originalDeviceName = deviceName;

  if ( !(deviceName.empty()) && ( deviceName[0] == 'X' ))// inside a subcircuit.  So, for the logic below, need to strip out everything until the last ":"
  {
    std::size_t found = deviceName.find_last_of(":");
    if ( found != std::string::npos) { deviceName = deviceName.substr(found+1); }
  }

  // allocate either a solution variable current object or a lead current object.  
  Teuchos::RCP<astNode<usedType> > tmpPtr;
  if ( !(deviceName.empty()) && ( 
        deviceName[0] == 'V' ||
        deviceName[0] == 'B' ||  // Bsrc's can be either one, but impossible to tell which at the expression parsing stage
        deviceName[0] == 'E' ||
        deviceName[0] == 'H' ||
        deviceName[0] == 'L' )) // solution variable current
  {
    // ensure that each current has a single, unique astNode allocated for it
    std::vector<std::string> & currentNameVec = newExp.getCurrentNameVec ();
    std::vector<Teuchos::RCP<astNode<usedType> > > & currentOpVec = newExp.getCurrentOpVec ();
    std::unordered_map<std::string,std::vector<Teuchos::RCP<astNode<usedType> > > > & currentOpMap = newExp.getLocalCurrentOpMap ();
    if ( currentOpMap.find(originalDeviceName) == currentOpMap.end() )
    {
      Teuchos::RCP<currentOp<usedType> > currentPtr = Teuchos::RCP<currentOp<usedType> >(new currentOp<usedType>(originalDeviceName));
      tmpPtr = Teuchos::RCP<astNode<usedType> >(currentPtr);
      currentOpVec.push_back(currentPtr);
      if (deviceName[0] == 'B')  
      { 
        (currentPtr)->setBsrcFlag();
        newExp.getBsrcCurrentOpVec().push_back(currentPtr);  // this object is necessary because Bsrc's can be either lead or solution var

        std::vector<std::string> & leadCurrentNameVec = newExp.getLeadCurrentNameVec();
        std::vector<std::string>::iterator nameIter = std::find(leadCurrentNameVec.begin(),leadCurrentNameVec.end(), originalDeviceName);
        if ( nameIter == leadCurrentNameVec.end() )
        {
          leadCurrentNameVec.push_back(originalDeviceName);
        }
      }
      currentNameVec.push_back( originalDeviceName );

      std::vector<Teuchos::RCP<astNode<usedType> > > vec;
      vec.push_back(currentPtr);
      currentOpMap[originalDeviceName] = vec;
    }
    else
    {
      tmpPtr = Teuchos::RCP<astNode<usedType> >(currentOpMap[ originalDeviceName  ][0]);
    }
  }
  else // lead current.  Previously, this block was below the "complex variant" block.  
       // Now it is here.  At present, no lead currents are complex numbers, but in theory that will change.
  {
    // lead currents are a little more tricky, so I'm not attempting to ensure uniqueness for now.
    Teuchos::RCP<leadCurrentOp<usedType> > leadCurrentPtr = Teuchos::RCP<leadCurrentOp<usedType> >(new leadCurrentOp<usedType>(firstArg,device));
    tmpPtr = Teuchos::RCP<astNode<usedType> >(leadCurrentPtr);
    newExp.getLeadCurrentOpVec().push_back(leadCurrentPtr);

    std::vector<std::string> & leadCurrentNameVec = newExp.getLeadCurrentNameVec();
    std::vector<std::string> & leadCurrentExcludeBsrcNameVec = newExp.getLeadCurrentExcludeBsrcNameVec();
    std::vector<std::string>::iterator nameIter = std::find(leadCurrentNameVec.begin(),leadCurrentNameVec.end(), originalDeviceName);
    if ( nameIter == leadCurrentNameVec.end() )
    {
      leadCurrentNameVec.push_back(originalDeviceName);
      leadCurrentExcludeBsrcNameVec.push_back(originalDeviceName);
    }
  }

  {
    // adjust for complex number variants
    if (firstArg.size() == 1)
    {
      returnPtr = tmpPtr;
    }
    else if (firstArg.size() == 2)
    {
       if ( firstArg == std::string("IR") )
       {
         returnPtr = Teuchos::RCP<astNode<usedType> >(new realOp<usedType>(tmpPtr));
       }
       else if ( firstArg == std::string("II") )
       {
         returnPtr = Teuchos::RCP<astNode<usedType> >(new imagOp<usedType>(tmpPtr));
       }
       else if ( firstArg == std::string("IM") )
       {
         returnPtr = Teuchos::RCP<astNode<usedType> >(new absOp<usedType>(tmpPtr));
       }
       else if ( firstArg == std::string("IP") )
       {
         returnPtr = Teuchos::RCP<astNode<usedType> >(new phaseOp<usedType>(tmpPtr));
         newExp.getPhaseOpVec().push_back(returnPtr);
       }
    }
    else if (firstArg.size() == 3) // do decibels here
    {
      if ( firstArg == std::string("IDB") )
      {
        // this needs to implement 20.0*std::log10(abs(tmpPtr))  
        Teuchos::RCP<astNode<usedType> > numvalPtr = Teuchos::RCP<astNode<usedType> >(new numval<usedType> (20.0));
        Teuchos::RCP<astNode<usedType> > absPtr = Teuchos::RCP<astNode<usedType> >(new absOp<usedType>(tmpPtr));
        Teuchos::RCP<astNode<usedType> > log10Ptr = Teuchos::RCP<astNode<usedType> >(new log10Op<usedType>(absPtr));
        returnPtr = Teuchos::RCP<astNode<usedType> >(new binaryMulOp<usedType>  (numvalPtr,log10Ptr));
      }
    }
    else
    {
      std::cout << "Unrecognized current operator " << firstArg << std::endl;
    }
  }
}


#line 635 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:413


#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> // FIXME: INFRINGES ON USER NAME SPACE.
#   define YY_(msgid) dgettext ("bison-runtime", msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(msgid) msgid
# endif
#endif

#define YYRHSLOC(Rhs, K) ((Rhs)[K].location)
/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
   If N is 0, then set CURRENT to the empty location which ends
   the previous symbol: RHS[0] (always defined).  */

# ifndef YYLLOC_DEFAULT
#  define YYLLOC_DEFAULT(Current, Rhs, N)                               \
    do                                                                  \
      if (N)                                                            \
        {                                                               \
          (Current).begin  = YYRHSLOC (Rhs, 1).begin;                   \
          (Current).end    = YYRHSLOC (Rhs, N).end;                     \
        }                                                               \
      else                                                              \
        {                                                               \
          (Current).begin = (Current).end = YYRHSLOC (Rhs, 0).end;      \
        }                                                               \
    while (/*CONSTCOND*/ false)
# endif


// Suppress unused-variable warnings by "using" E.
#define YYUSE(E) ((void) (E))

// Enable debugging if requested.
#if XYCEEXPRESSIONDEBUG

// A pseudo ostream that takes yydebug_ into account.
# define YYCDEBUG if (yydebug_) (*yycdebug_)

# define YY_SYMBOL_PRINT(Title, Symbol)         \
  do {                                          \
    if (yydebug_)                               \
    {                                           \
      *yycdebug_ << Title << ' ';               \
      yy_print_ (*yycdebug_, Symbol);           \
      *yycdebug_ << std::endl;                  \
    }                                           \
  } while (false)

# define YY_REDUCE_PRINT(Rule)          \
  do {                                  \
    if (yydebug_)                       \
      yy_reduce_print_ (Rule);          \
  } while (false)

# define YY_STACK_PRINT()               \
  do {                                  \
    if (yydebug_)                       \
      yystack_print_ ();                \
  } while (false)

#else // !XYCEEXPRESSIONDEBUG

# define YYCDEBUG if (false) std::cerr
# define YY_SYMBOL_PRINT(Title, Symbol)  YYUSE(Symbol)
# define YY_REDUCE_PRINT(Rule)           static_cast<void>(0)
# define YY_STACK_PRINT()                static_cast<void>(0)

#endif // !XYCEEXPRESSIONDEBUG

#define yyerrok         (yyerrstatus_ = 0)
#define yyclearin       (yyla.clear ())

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab
#define YYRECOVERING()  (!!yyerrstatus_)


namespace XyceExpression {
#line 721 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:479

  /// Build a parser object.
  ExpressionParser::ExpressionParser (Xyce::Util::ExpressionLexer *theLexer_yyarg, Xyce::Util::newExpression & newExp_yyarg)
    :
#if XYCEEXPRESSIONDEBUG
      yydebug_ (false),
      yycdebug_ (&std::cerr),
#endif
      theLexer (theLexer_yyarg),
      newExp (newExp_yyarg)
  {}

  ExpressionParser::~ExpressionParser ()
  {}


  /*---------------.
  | Symbol types.  |
  `---------------*/

  inline
  ExpressionParser::syntax_error::syntax_error (const location_type& l, const std::string& m)
    : std::runtime_error (m)
    , location (l)
  {}

  // basic_symbol.
  template <typename Base>
  inline
  ExpressionParser::basic_symbol<Base>::basic_symbol ()
    : value ()
  {}

  template <typename Base>
  inline
  ExpressionParser::basic_symbol<Base>::basic_symbol (const basic_symbol& other)
    : Base (other)
    , value ()
    , location (other.location)
  {
      switch (other.type_get ())
    {
      case 140: // expression
      case 141: // exp
      case 150: // polyarg
        value.copy< Teuchos::RCP<astNode<usedType> >  > (other.value);
        break;

      case 153: // table_threeOrFourArgs
      case 154: // table2_threeOrFourArgs
      case 155: // table3_threeOrFourArgs
        value.copy< Xyce::Util::tableArgs<usedType>  > (other.value);
        break;

      case 3: // "polysize"
      case 4: // "polycoef"
      case 5: // "num"
      case 6: // "imag_num"
      case 151: // paren_polycoef
        value.copy< double > (other.value);
        break;

      case 26: // "rf_param_arg"
        value.copy< int > (other.value);
        break;

      case 149: // polypair
        value.copy< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > (other.value);
        break;

      case 7: // "word"
      case 8: // "filename"
      case 9: // "function"
      case 10: // "lead"
      case 11: // "onoise"
      case 12: // "inoise"
      case 13: // "power"
      case 14: // "voltage"
      case 15: // "voltagenode"
      case 16: // "poly_voltage"
      case 17: // "current"
      case 18: // "currentdevice"
      case 19: // "poly_current"
      case 20: // "poly_word"
      case 21: // "internal_variable"
      case 22: // "internal_variable_device"
      case 23: // "noise"
      case 24: // "noise_device_variable"
      case 25: // "rfparam"
      case 27: // "table"
      case 28: // "table2"
      case 29: // "table3"
      case 30: // "tablefile"
      case 152: // paren_polyword
        value.copy< std::string * > (other.value);
        break;

      case 145: // nonempty_func_arglist
      case 146: // nonempty_func_arglist2
      case 147: // two_or_more_arglist
      case 148: // nonempty_arg_pairs
        value.copy< std::vector< Teuchos::RCP<astNode<usedType> > > * > (other.value);
        break;

      case 142: // nonempty_rfparam_arg_list
        value.copy< std::vector<int> * > (other.value);
        break;

      case 143: // nonempty_noise_device_list
      case 144: // nonempty_voltagenodelist
        value.copy< std::vector<std::string> * > (other.value);
        break;

      default:
        break;
    }

  }


  template <typename Base>
  inline
  ExpressionParser::basic_symbol<Base>::basic_symbol (typename Base::kind_type t, const semantic_type& v, const location_type& l)
    : Base (t)
    , value ()
    , location (l)
  {
    (void) v;
      switch (this->type_get ())
    {
      case 140: // expression
      case 141: // exp
      case 150: // polyarg
        value.copy< Teuchos::RCP<astNode<usedType> >  > (v);
        break;

      case 153: // table_threeOrFourArgs
      case 154: // table2_threeOrFourArgs
      case 155: // table3_threeOrFourArgs
        value.copy< Xyce::Util::tableArgs<usedType>  > (v);
        break;

      case 3: // "polysize"
      case 4: // "polycoef"
      case 5: // "num"
      case 6: // "imag_num"
      case 151: // paren_polycoef
        value.copy< double > (v);
        break;

      case 26: // "rf_param_arg"
        value.copy< int > (v);
        break;

      case 149: // polypair
        value.copy< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > (v);
        break;

      case 7: // "word"
      case 8: // "filename"
      case 9: // "function"
      case 10: // "lead"
      case 11: // "onoise"
      case 12: // "inoise"
      case 13: // "power"
      case 14: // "voltage"
      case 15: // "voltagenode"
      case 16: // "poly_voltage"
      case 17: // "current"
      case 18: // "currentdevice"
      case 19: // "poly_current"
      case 20: // "poly_word"
      case 21: // "internal_variable"
      case 22: // "internal_variable_device"
      case 23: // "noise"
      case 24: // "noise_device_variable"
      case 25: // "rfparam"
      case 27: // "table"
      case 28: // "table2"
      case 29: // "table3"
      case 30: // "tablefile"
      case 152: // paren_polyword
        value.copy< std::string * > (v);
        break;

      case 145: // nonempty_func_arglist
      case 146: // nonempty_func_arglist2
      case 147: // two_or_more_arglist
      case 148: // nonempty_arg_pairs
        value.copy< std::vector< Teuchos::RCP<astNode<usedType> > > * > (v);
        break;

      case 142: // nonempty_rfparam_arg_list
        value.copy< std::vector<int> * > (v);
        break;

      case 143: // nonempty_noise_device_list
      case 144: // nonempty_voltagenodelist
        value.copy< std::vector<std::string> * > (v);
        break;

      default:
        break;
    }
}


  // Implementation of basic_symbol constructor for each type.

  template <typename Base>
  ExpressionParser::basic_symbol<Base>::basic_symbol (typename Base::kind_type t, const location_type& l)
    : Base (t)
    , value ()
    , location (l)
  {}

  template <typename Base>
  ExpressionParser::basic_symbol<Base>::basic_symbol (typename Base::kind_type t, const Teuchos::RCP<astNode<usedType> >  v, const location_type& l)
    : Base (t)
    , value (v)
    , location (l)
  {}

  template <typename Base>
  ExpressionParser::basic_symbol<Base>::basic_symbol (typename Base::kind_type t, const Xyce::Util::tableArgs<usedType>  v, const location_type& l)
    : Base (t)
    , value (v)
    , location (l)
  {}

  template <typename Base>
  ExpressionParser::basic_symbol<Base>::basic_symbol (typename Base::kind_type t, const double v, const location_type& l)
    : Base (t)
    , value (v)
    , location (l)
  {}

  template <typename Base>
  ExpressionParser::basic_symbol<Base>::basic_symbol (typename Base::kind_type t, const int v, const location_type& l)
    : Base (t)
    , value (v)
    , location (l)
  {}

  template <typename Base>
  ExpressionParser::basic_symbol<Base>::basic_symbol (typename Base::kind_type t, const std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * v, const location_type& l)
    : Base (t)
    , value (v)
    , location (l)
  {}

  template <typename Base>
  ExpressionParser::basic_symbol<Base>::basic_symbol (typename Base::kind_type t, const std::string * v, const location_type& l)
    : Base (t)
    , value (v)
    , location (l)
  {}

  template <typename Base>
  ExpressionParser::basic_symbol<Base>::basic_symbol (typename Base::kind_type t, const std::vector< Teuchos::RCP<astNode<usedType> > > * v, const location_type& l)
    : Base (t)
    , value (v)
    , location (l)
  {}

  template <typename Base>
  ExpressionParser::basic_symbol<Base>::basic_symbol (typename Base::kind_type t, const std::vector<int> * v, const location_type& l)
    : Base (t)
    , value (v)
    , location (l)
  {}

  template <typename Base>
  ExpressionParser::basic_symbol<Base>::basic_symbol (typename Base::kind_type t, const std::vector<std::string> * v, const location_type& l)
    : Base (t)
    , value (v)
    , location (l)
  {}


  template <typename Base>
  inline
  ExpressionParser::basic_symbol<Base>::~basic_symbol ()
  {
    clear ();
  }

  template <typename Base>
  inline
  void
  ExpressionParser::basic_symbol<Base>::clear ()
  {
    // User destructor.
    symbol_number_type yytype = this->type_get ();
    basic_symbol<Base>& yysym = *this;
    (void) yysym;
    switch (yytype)
    {
      case 15: // "voltagenode"

#line 760 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:536
        { delete yysym.value.template as< std::string * > (); }
#line 1024 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:536
        break;

      case 24: // "noise_device_variable"

#line 761 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:536
        { delete yysym.value.template as< std::string * > (); }
#line 1031 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:536
        break;

      case 30: // "tablefile"

#line 762 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:536
        { delete yysym.value.template as< std::string * > (); }
#line 1038 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:536
        break;

   default:
      break;
    }

    // Type destructor.
    switch (yytype)
    {
      case 140: // expression
      case 141: // exp
      case 150: // polyarg
        value.template destroy< Teuchos::RCP<astNode<usedType> >  > ();
        break;

      case 153: // table_threeOrFourArgs
      case 154: // table2_threeOrFourArgs
      case 155: // table3_threeOrFourArgs
        value.template destroy< Xyce::Util::tableArgs<usedType>  > ();
        break;

      case 3: // "polysize"
      case 4: // "polycoef"
      case 5: // "num"
      case 6: // "imag_num"
      case 151: // paren_polycoef
        value.template destroy< double > ();
        break;

      case 26: // "rf_param_arg"
        value.template destroy< int > ();
        break;

      case 149: // polypair
        value.template destroy< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > ();
        break;

      case 7: // "word"
      case 8: // "filename"
      case 9: // "function"
      case 10: // "lead"
      case 11: // "onoise"
      case 12: // "inoise"
      case 13: // "power"
      case 14: // "voltage"
      case 15: // "voltagenode"
      case 16: // "poly_voltage"
      case 17: // "current"
      case 18: // "currentdevice"
      case 19: // "poly_current"
      case 20: // "poly_word"
      case 21: // "internal_variable"
      case 22: // "internal_variable_device"
      case 23: // "noise"
      case 24: // "noise_device_variable"
      case 25: // "rfparam"
      case 27: // "table"
      case 28: // "table2"
      case 29: // "table3"
      case 30: // "tablefile"
      case 152: // paren_polyword
        value.template destroy< std::string * > ();
        break;

      case 145: // nonempty_func_arglist
      case 146: // nonempty_func_arglist2
      case 147: // two_or_more_arglist
      case 148: // nonempty_arg_pairs
        value.template destroy< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
        break;

      case 142: // nonempty_rfparam_arg_list
        value.template destroy< std::vector<int> * > ();
        break;

      case 143: // nonempty_noise_device_list
      case 144: // nonempty_voltagenodelist
        value.template destroy< std::vector<std::string> * > ();
        break;

      default:
        break;
    }

    Base::clear ();
  }

  template <typename Base>
  inline
  bool
  ExpressionParser::basic_symbol<Base>::empty () const
  {
    return Base::type_get () == empty_symbol;
  }

  template <typename Base>
  inline
  void
  ExpressionParser::basic_symbol<Base>::move (basic_symbol& s)
  {
    super_type::move(s);
      switch (this->type_get ())
    {
      case 140: // expression
      case 141: // exp
      case 150: // polyarg
        value.move< Teuchos::RCP<astNode<usedType> >  > (s.value);
        break;

      case 153: // table_threeOrFourArgs
      case 154: // table2_threeOrFourArgs
      case 155: // table3_threeOrFourArgs
        value.move< Xyce::Util::tableArgs<usedType>  > (s.value);
        break;

      case 3: // "polysize"
      case 4: // "polycoef"
      case 5: // "num"
      case 6: // "imag_num"
      case 151: // paren_polycoef
        value.move< double > (s.value);
        break;

      case 26: // "rf_param_arg"
        value.move< int > (s.value);
        break;

      case 149: // polypair
        value.move< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > (s.value);
        break;

      case 7: // "word"
      case 8: // "filename"
      case 9: // "function"
      case 10: // "lead"
      case 11: // "onoise"
      case 12: // "inoise"
      case 13: // "power"
      case 14: // "voltage"
      case 15: // "voltagenode"
      case 16: // "poly_voltage"
      case 17: // "current"
      case 18: // "currentdevice"
      case 19: // "poly_current"
      case 20: // "poly_word"
      case 21: // "internal_variable"
      case 22: // "internal_variable_device"
      case 23: // "noise"
      case 24: // "noise_device_variable"
      case 25: // "rfparam"
      case 27: // "table"
      case 28: // "table2"
      case 29: // "table3"
      case 30: // "tablefile"
      case 152: // paren_polyword
        value.move< std::string * > (s.value);
        break;

      case 145: // nonempty_func_arglist
      case 146: // nonempty_func_arglist2
      case 147: // two_or_more_arglist
      case 148: // nonempty_arg_pairs
        value.move< std::vector< Teuchos::RCP<astNode<usedType> > > * > (s.value);
        break;

      case 142: // nonempty_rfparam_arg_list
        value.move< std::vector<int> * > (s.value);
        break;

      case 143: // nonempty_noise_device_list
      case 144: // nonempty_voltagenodelist
        value.move< std::vector<std::string> * > (s.value);
        break;

      default:
        break;
    }

    location = s.location;
  }

  // by_type.
  inline
  ExpressionParser::by_type::by_type ()
    : type (empty_symbol)
  {}

  inline
  ExpressionParser::by_type::by_type (const by_type& other)
    : type (other.type)
  {}

  inline
  ExpressionParser::by_type::by_type (token_type t)
    : type (yytranslate_ (t))
  {}

  inline
  void
  ExpressionParser::by_type::clear ()
  {
    type = empty_symbol;
  }

  inline
  void
  ExpressionParser::by_type::move (by_type& that)
  {
    type = that.type;
    that.clear ();
  }

  inline
  int
  ExpressionParser::by_type::type_get () const
  {
    return type;
  }
  // Implementation of make_symbol for each symbol type.
  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_POLYSIZE (const double& v, const location_type& l)
  {
    return symbol_type (token::TOK_POLYSIZE, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_POLYCOEF (const double& v, const location_type& l)
  {
    return symbol_type (token::TOK_POLYCOEF, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_NUM (const double& v, const location_type& l)
  {
    return symbol_type (token::TOK_NUM, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_IMAG_NUM (const double& v, const location_type& l)
  {
    return symbol_type (token::TOK_IMAG_NUM, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_WORD (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_WORD, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_FILENAME (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_FILENAME, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_FUNCTION (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_FUNCTION, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_LEAD (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_LEAD, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_ONOISE (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_ONOISE, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_INOISE (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_INOISE, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_POWER (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_POWER, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_VOLTAGE (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_VOLTAGE, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_VOLTAGENODE (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_VOLTAGENODE, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_POLY_VOLTAGE (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_POLY_VOLTAGE, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_CURRENT (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_CURRENT, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_CURRENTDEV (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_CURRENTDEV, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_POLY_CURRENT (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_POLY_CURRENT, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_POLY_WORD (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_POLY_WORD, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_INTERNAL_VAR (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_INTERNAL_VAR, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_INTERNAL_VAR_DEV (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_INTERNAL_VAR_DEV, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_NOISE (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_NOISE, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_NOISE_DEV_VAR (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_NOISE_DEV_VAR, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_RFPARAM (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_RFPARAM, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_RFPARAM_ARG (const int& v, const location_type& l)
  {
    return symbol_type (token::TOK_RFPARAM_ARG, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_TABLE (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_TABLE, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_TABLE2 (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_TABLE2, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_TABLE3 (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_TABLE3, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_TABLEFILE (const std::string *& v, const location_type& l)
  {
    return symbol_type (token::TOK_TABLEFILE, v, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SQRT (const location_type& l)
  {
    return symbol_type (token::TOK_SQRT, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_MAX (const location_type& l)
  {
    return symbol_type (token::TOK_MAX, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_MIN (const location_type& l)
  {
    return symbol_type (token::TOK_MIN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_PHASE (const location_type& l)
  {
    return symbol_type (token::TOK_PHASE, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_REAL (const location_type& l)
  {
    return symbol_type (token::TOK_REAL, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_IMAG (const location_type& l)
  {
    return symbol_type (token::TOK_IMAG, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_DB (const location_type& l)
  {
    return symbol_type (token::TOK_DB, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_EXP (const location_type& l)
  {
    return symbol_type (token::TOK_EXP, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_EXP_CONST (const location_type& l)
  {
    return symbol_type (token::TOK_EXP_CONST, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SIN (const location_type& l)
  {
    return symbol_type (token::TOK_SIN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_COS (const location_type& l)
  {
    return symbol_type (token::TOK_COS, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_MABS (const location_type& l)
  {
    return symbol_type (token::TOK_MABS, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_ABS (const location_type& l)
  {
    return symbol_type (token::TOK_ABS, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_ACOS (const location_type& l)
  {
    return symbol_type (token::TOK_ACOS, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_ACOSH (const location_type& l)
  {
    return symbol_type (token::TOK_ACOSH, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_ASIN (const location_type& l)
  {
    return symbol_type (token::TOK_ASIN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_ASINH (const location_type& l)
  {
    return symbol_type (token::TOK_ASINH, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_ATAN2 (const location_type& l)
  {
    return symbol_type (token::TOK_ATAN2, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_ATAN (const location_type& l)
  {
    return symbol_type (token::TOK_ATAN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_ATANH (const location_type& l)
  {
    return symbol_type (token::TOK_ATANH, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_COSH (const location_type& l)
  {
    return symbol_type (token::TOK_COSH, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_LN (const location_type& l)
  {
    return symbol_type (token::TOK_LN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_LOG (const location_type& l)
  {
    return symbol_type (token::TOK_LOG, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_LOG10 (const location_type& l)
  {
    return symbol_type (token::TOK_LOG10, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SINH (const location_type& l)
  {
    return symbol_type (token::TOK_SINH, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_TAN (const location_type& l)
  {
    return symbol_type (token::TOK_TAN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_TANH (const location_type& l)
  {
    return symbol_type (token::TOK_TANH, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_IF (const location_type& l)
  {
    return symbol_type (token::TOK_IF, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_EQUALS (const location_type& l)
  {
    return symbol_type (token::TOK_EQUALS, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SEMICOLON (const location_type& l)
  {
    return symbol_type (token::TOK_SEMICOLON, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_AUNIF (const location_type& l)
  {
    return symbol_type (token::TOK_AUNIF, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_UNIF (const location_type& l)
  {
    return symbol_type (token::TOK_UNIF, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_AGAUSS (const location_type& l)
  {
    return symbol_type (token::TOK_AGAUSS, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_FMOD (const location_type& l)
  {
    return symbol_type (token::TOK_FMOD, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_NINT (const location_type& l)
  {
    return symbol_type (token::TOK_NINT, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_CEIL (const location_type& l)
  {
    return symbol_type (token::TOK_CEIL, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_GAUSS (const location_type& l)
  {
    return symbol_type (token::TOK_GAUSS, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_DDT (const location_type& l)
  {
    return symbol_type (token::TOK_DDT, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_DDX (const location_type& l)
  {
    return symbol_type (token::TOK_DDX, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_FLOOR (const location_type& l)
  {
    return symbol_type (token::TOK_FLOOR, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_INT (const location_type& l)
  {
    return symbol_type (token::TOK_INT, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_LIMIT (const location_type& l)
  {
    return symbol_type (token::TOK_LIMIT, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_POWSFUNC (const location_type& l)
  {
    return symbol_type (token::TOK_POWSFUNC, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_RAND (const location_type& l)
  {
    return symbol_type (token::TOK_RAND, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SDT (const location_type& l)
  {
    return symbol_type (token::TOK_SDT, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SGN (const location_type& l)
  {
    return symbol_type (token::TOK_SGN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SIGN (const location_type& l)
  {
    return symbol_type (token::TOK_SIGN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_STP (const location_type& l)
  {
    return symbol_type (token::TOK_STP, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_TABLEFILE_END (const location_type& l)
  {
    return symbol_type (token::TOK_TABLEFILE_END, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SCHEDULE (const location_type& l)
  {
    return symbol_type (token::TOK_SCHEDULE, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_URAMP (const location_type& l)
  {
    return symbol_type (token::TOK_URAMP, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_BADPOLY (const location_type& l)
  {
    return symbol_type (token::TOK_BADPOLY, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SPICE_PULSE (const location_type& l)
  {
    return symbol_type (token::TOK_SPICE_PULSE, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SPICE_SIN (const location_type& l)
  {
    return symbol_type (token::TOK_SPICE_SIN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SPICE_EXP (const location_type& l)
  {
    return symbol_type (token::TOK_SPICE_EXP, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_SPICE_SFFM (const location_type& l)
  {
    return symbol_type (token::TOK_SPICE_SFFM, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_DT (const location_type& l)
  {
    return symbol_type (token::TOK_DT, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_TIME (const location_type& l)
  {
    return symbol_type (token::TOK_TIME, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_TEMP (const location_type& l)
  {
    return symbol_type (token::TOK_TEMP, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_VT (const location_type& l)
  {
    return symbol_type (token::TOK_VT, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_FREQ (const location_type& l)
  {
    return symbol_type (token::TOK_FREQ, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_GMIN (const location_type& l)
  {
    return symbol_type (token::TOK_GMIN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_PI (const location_type& l)
  {
    return symbol_type (token::TOK_PI, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_C_TO_K (const location_type& l)
  {
    return symbol_type (token::TOK_C_TO_K, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_RIGHTPAREN (const location_type& l)
  {
    return symbol_type (token::TOK_RIGHTPAREN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_LEFTPAREN (const location_type& l)
  {
    return symbol_type (token::TOK_LEFTPAREN, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_RIGHTCURLYBRACE (const location_type& l)
  {
    return symbol_type (token::TOK_RIGHTCURLYBRACE, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_LEFTCURLYBRACE (const location_type& l)
  {
    return symbol_type (token::TOK_LEFTCURLYBRACE, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_COMMA (const location_type& l)
  {
    return symbol_type (token::TOK_COMMA, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_QUESTION_MARK (const location_type& l)
  {
    return symbol_type (token::TOK_QUESTION_MARK, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_COLON (const location_type& l)
  {
    return symbol_type (token::TOK_COLON, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_OR (const location_type& l)
  {
    return symbol_type (token::TOK_OR, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_AND (const location_type& l)
  {
    return symbol_type (token::TOK_AND, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_NOT (const location_type& l)
  {
    return symbol_type (token::TOK_NOT, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_CARET (const location_type& l)
  {
    return symbol_type (token::TOK_CARET, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_EQ (const location_type& l)
  {
    return symbol_type (token::TOK_EQ, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_NE (const location_type& l)
  {
    return symbol_type (token::TOK_NE, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_LE (const location_type& l)
  {
    return symbol_type (token::TOK_LE, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_LT (const location_type& l)
  {
    return symbol_type (token::TOK_LT, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_GE (const location_type& l)
  {
    return symbol_type (token::TOK_GE, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_GT (const location_type& l)
  {
    return symbol_type (token::TOK_GT, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_INVALID_OP (const location_type& l)
  {
    return symbol_type (token::TOK_INVALID_OP, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_MINUS (const location_type& l)
  {
    return symbol_type (token::TOK_MINUS, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_PLUS (const location_type& l)
  {
    return symbol_type (token::TOK_PLUS, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_MOD (const location_type& l)
  {
    return symbol_type (token::TOK_MOD, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_MULTIPLY (const location_type& l)
  {
    return symbol_type (token::TOK_MULTIPLY, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_DIVIDE (const location_type& l)
  {
    return symbol_type (token::TOK_DIVIDE, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_NEG (const location_type& l)
  {
    return symbol_type (token::NEG, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_POW (const location_type& l)
  {
    return symbol_type (token::TOK_POW, l);
  }

  ExpressionParser::symbol_type
  ExpressionParser::make_TOK_POWFUNC (const location_type& l)
  {
    return symbol_type (token::TOK_POWFUNC, l);
  }



  // by_state.
  inline
  ExpressionParser::by_state::by_state ()
    : state (empty_state)
  {}

  inline
  ExpressionParser::by_state::by_state (const by_state& other)
    : state (other.state)
  {}

  inline
  void
  ExpressionParser::by_state::clear ()
  {
    state = empty_state;
  }

  inline
  void
  ExpressionParser::by_state::move (by_state& that)
  {
    state = that.state;
    that.clear ();
  }

  inline
  ExpressionParser::by_state::by_state (state_type s)
    : state (s)
  {}

  inline
  ExpressionParser::symbol_number_type
  ExpressionParser::by_state::type_get () const
  {
    if (state == empty_state)
      return empty_symbol;
    else
      return yystos_[state];
  }

  inline
  ExpressionParser::stack_symbol_type::stack_symbol_type ()
  {}


  inline
  ExpressionParser::stack_symbol_type::stack_symbol_type (state_type s, symbol_type& that)
    : super_type (s, that.location)
  {
      switch (that.type_get ())
    {
      case 140: // expression
      case 141: // exp
      case 150: // polyarg
        value.move< Teuchos::RCP<astNode<usedType> >  > (that.value);
        break;

      case 153: // table_threeOrFourArgs
      case 154: // table2_threeOrFourArgs
      case 155: // table3_threeOrFourArgs
        value.move< Xyce::Util::tableArgs<usedType>  > (that.value);
        break;

      case 3: // "polysize"
      case 4: // "polycoef"
      case 5: // "num"
      case 6: // "imag_num"
      case 151: // paren_polycoef
        value.move< double > (that.value);
        break;

      case 26: // "rf_param_arg"
        value.move< int > (that.value);
        break;

      case 149: // polypair
        value.move< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > (that.value);
        break;

      case 7: // "word"
      case 8: // "filename"
      case 9: // "function"
      case 10: // "lead"
      case 11: // "onoise"
      case 12: // "inoise"
      case 13: // "power"
      case 14: // "voltage"
      case 15: // "voltagenode"
      case 16: // "poly_voltage"
      case 17: // "current"
      case 18: // "currentdevice"
      case 19: // "poly_current"
      case 20: // "poly_word"
      case 21: // "internal_variable"
      case 22: // "internal_variable_device"
      case 23: // "noise"
      case 24: // "noise_device_variable"
      case 25: // "rfparam"
      case 27: // "table"
      case 28: // "table2"
      case 29: // "table3"
      case 30: // "tablefile"
      case 152: // paren_polyword
        value.move< std::string * > (that.value);
        break;

      case 145: // nonempty_func_arglist
      case 146: // nonempty_func_arglist2
      case 147: // two_or_more_arglist
      case 148: // nonempty_arg_pairs
        value.move< std::vector< Teuchos::RCP<astNode<usedType> > > * > (that.value);
        break;

      case 142: // nonempty_rfparam_arg_list
        value.move< std::vector<int> * > (that.value);
        break;

      case 143: // nonempty_noise_device_list
      case 144: // nonempty_voltagenodelist
        value.move< std::vector<std::string> * > (that.value);
        break;

      default:
        break;
    }

    // that is emptied.
    that.type = empty_symbol;
  }

  inline
  ExpressionParser::stack_symbol_type&
  ExpressionParser::stack_symbol_type::operator= (const stack_symbol_type& that)
  {
    state = that.state;
      switch (that.type_get ())
    {
      case 140: // expression
      case 141: // exp
      case 150: // polyarg
        value.copy< Teuchos::RCP<astNode<usedType> >  > (that.value);
        break;

      case 153: // table_threeOrFourArgs
      case 154: // table2_threeOrFourArgs
      case 155: // table3_threeOrFourArgs
        value.copy< Xyce::Util::tableArgs<usedType>  > (that.value);
        break;

      case 3: // "polysize"
      case 4: // "polycoef"
      case 5: // "num"
      case 6: // "imag_num"
      case 151: // paren_polycoef
        value.copy< double > (that.value);
        break;

      case 26: // "rf_param_arg"
        value.copy< int > (that.value);
        break;

      case 149: // polypair
        value.copy< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > (that.value);
        break;

      case 7: // "word"
      case 8: // "filename"
      case 9: // "function"
      case 10: // "lead"
      case 11: // "onoise"
      case 12: // "inoise"
      case 13: // "power"
      case 14: // "voltage"
      case 15: // "voltagenode"
      case 16: // "poly_voltage"
      case 17: // "current"
      case 18: // "currentdevice"
      case 19: // "poly_current"
      case 20: // "poly_word"
      case 21: // "internal_variable"
      case 22: // "internal_variable_device"
      case 23: // "noise"
      case 24: // "noise_device_variable"
      case 25: // "rfparam"
      case 27: // "table"
      case 28: // "table2"
      case 29: // "table3"
      case 30: // "tablefile"
      case 152: // paren_polyword
        value.copy< std::string * > (that.value);
        break;

      case 145: // nonempty_func_arglist
      case 146: // nonempty_func_arglist2
      case 147: // two_or_more_arglist
      case 148: // nonempty_arg_pairs
        value.copy< std::vector< Teuchos::RCP<astNode<usedType> > > * > (that.value);
        break;

      case 142: // nonempty_rfparam_arg_list
        value.copy< std::vector<int> * > (that.value);
        break;

      case 143: // nonempty_noise_device_list
      case 144: // nonempty_voltagenodelist
        value.copy< std::vector<std::string> * > (that.value);
        break;

      default:
        break;
    }

    location = that.location;
    return *this;
  }


  template <typename Base>
  inline
  void
  ExpressionParser::yy_destroy_ (const char* yymsg, basic_symbol<Base>& yysym) const
  {
    if (yymsg)
      YY_SYMBOL_PRINT (yymsg, yysym);
  }

#if XYCEEXPRESSIONDEBUG
  template <typename Base>
  void
  ExpressionParser::yy_print_ (std::ostream& yyo,
                                     const basic_symbol<Base>& yysym) const
  {
    std::ostream& yyoutput = yyo;
    YYUSE (yyoutput);
    symbol_number_type yytype = yysym.type_get ();
    // Avoid a (spurious) G++ 4.8 warning about "array subscript is
    // below array bounds".
    if (yysym.empty ())
      std::abort ();
    yyo << (yytype < yyntokens_ ? "token" : "nterm")
        << ' ' << yytname_[yytype] << " ("
        << yysym.location << ": ";
    YYUSE (yytype);
    yyo << ')';
  }
#endif

  inline
  void
  ExpressionParser::yypush_ (const char* m, state_type s, symbol_type& sym)
  {
    stack_symbol_type t (s, sym);
    yypush_ (m, t);
  }

  inline
  void
  ExpressionParser::yypush_ (const char* m, stack_symbol_type& s)
  {
    if (m)
      YY_SYMBOL_PRINT (m, s);
    yystack_.push (s);
  }

  inline
  void
  ExpressionParser::yypop_ (unsigned int n)
  {
    yystack_.pop (n);
  }

#if XYCEEXPRESSIONDEBUG
  std::ostream&
  ExpressionParser::debug_stream () const
  {
    return *yycdebug_;
  }

  void
  ExpressionParser::set_debug_stream (std::ostream& o)
  {
    yycdebug_ = &o;
  }


  ExpressionParser::debug_level_type
  ExpressionParser::debug_level () const
  {
    return yydebug_;
  }

  void
  ExpressionParser::set_debug_level (debug_level_type l)
  {
    yydebug_ = l;
  }
#endif // XYCEEXPRESSIONDEBUG

  inline ExpressionParser::state_type
  ExpressionParser::yy_lr_goto_state_ (state_type yystate, int yysym)
  {
    int yyr = yypgoto_[yysym - yyntokens_] + yystate;
    if (0 <= yyr && yyr <= yylast_ && yycheck_[yyr] == yystate)
      return yytable_[yyr];
    else
      return yydefgoto_[yysym - yyntokens_];
  }

  inline bool
  ExpressionParser::yy_pact_value_is_default_ (int yyvalue)
  {
    return yyvalue == yypact_ninf_;
  }

  inline bool
  ExpressionParser::yy_table_value_is_error_ (int yyvalue)
  {
    return yyvalue == yytable_ninf_;
  }

  int
  ExpressionParser::parse ()
  {
    // State.
    int yyn;
    /// Length of the RHS of the rule being reduced.
    int yylen = 0;

    // Error handling.
    int yynerrs_ = 0;
    int yyerrstatus_ = 0;

    /// The lookahead symbol.
    symbol_type yyla;

    /// The locations where the error started and ended.
    stack_symbol_type yyerror_range[3];

    /// The return value of parse ().
    int yyresult;

    // FIXME: This shoud be completely indented.  It is not yet to
    // avoid gratuitous conflicts when merging into the master branch.
    try
      {
    YYCDEBUG << "Starting parse" << std::endl;


    /* Initialize the stack.  The initial state will be set in
       yynewstate, since the latter expects the semantical and the
       location values to have been already stored, initialize these
       stacks with a primary value.  */
    yystack_.clear ();
    yypush_ (YY_NULLPTR, 0, yyla);

    // A new symbol was pushed on the stack.
  yynewstate:
    YYCDEBUG << "Entering state " << yystack_[0].state << std::endl;

    // Accept?
    if (yystack_[0].state == yyfinal_)
      goto yyacceptlab;

    goto yybackup;

    // Backup.
  yybackup:

    // Try to take a decision without lookahead.
    yyn = yypact_[yystack_[0].state];
    if (yy_pact_value_is_default_ (yyn))
      goto yydefault;

    // Read a lookahead token.
    if (yyla.empty ())
      {
        YYCDEBUG << "Reading a token: ";
        try
          {
            yyla.type = yytranslate_ (yylex (&yyla.value, &yyla.location, theLexer));
          }
        catch (const syntax_error& yyexc)
          {
            error (yyexc);
            goto yyerrlab1;
          }
      }
    YY_SYMBOL_PRINT ("Next token is", yyla);

    /* If the proper action on seeing token YYLA.TYPE is to reduce or
       to detect an error, take that action.  */
    yyn += yyla.type_get ();
    if (yyn < 0 || yylast_ < yyn || yycheck_[yyn] != yyla.type_get ())
      goto yydefault;

    // Reduce or error.
    yyn = yytable_[yyn];
    if (yyn <= 0)
      {
        if (yy_table_value_is_error_ (yyn))
          goto yyerrlab;
        yyn = -yyn;
        goto yyreduce;
      }

    // Count tokens shifted since error; after three, turn off error status.
    if (yyerrstatus_)
      --yyerrstatus_;

    // Shift the lookahead token.
    yypush_ ("Shifting", yyn, yyla);
    goto yynewstate;

  /*-----------------------------------------------------------.
  | yydefault -- do the default action for the current state.  |
  `-----------------------------------------------------------*/
  yydefault:
    yyn = yydefact_[yystack_[0].state];
    if (yyn == 0)
      goto yyerrlab;
    goto yyreduce;

  /*-----------------------------.
  | yyreduce -- Do a reduction.  |
  `-----------------------------*/
  yyreduce:
    yylen = yyr2_[yyn];
    {
      stack_symbol_type yylhs;
      yylhs.state = yy_lr_goto_state_(yystack_[yylen].state, yyr1_[yyn]);
      /* Variants are always initialized to an empty instance of the
         correct type. The default '$$ = $1' action is NOT applied
         when using variants.  */
        switch (yyr1_[yyn])
    {
      case 140: // expression
      case 141: // exp
      case 150: // polyarg
        yylhs.value.build< Teuchos::RCP<astNode<usedType> >  > ();
        break;

      case 153: // table_threeOrFourArgs
      case 154: // table2_threeOrFourArgs
      case 155: // table3_threeOrFourArgs
        yylhs.value.build< Xyce::Util::tableArgs<usedType>  > ();
        break;

      case 3: // "polysize"
      case 4: // "polycoef"
      case 5: // "num"
      case 6: // "imag_num"
      case 151: // paren_polycoef
        yylhs.value.build< double > ();
        break;

      case 26: // "rf_param_arg"
        yylhs.value.build< int > ();
        break;

      case 149: // polypair
        yylhs.value.build< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > ();
        break;

      case 7: // "word"
      case 8: // "filename"
      case 9: // "function"
      case 10: // "lead"
      case 11: // "onoise"
      case 12: // "inoise"
      case 13: // "power"
      case 14: // "voltage"
      case 15: // "voltagenode"
      case 16: // "poly_voltage"
      case 17: // "current"
      case 18: // "currentdevice"
      case 19: // "poly_current"
      case 20: // "poly_word"
      case 21: // "internal_variable"
      case 22: // "internal_variable_device"
      case 23: // "noise"
      case 24: // "noise_device_variable"
      case 25: // "rfparam"
      case 27: // "table"
      case 28: // "table2"
      case 29: // "table3"
      case 30: // "tablefile"
      case 152: // paren_polyword
        yylhs.value.build< std::string * > ();
        break;

      case 145: // nonempty_func_arglist
      case 146: // nonempty_func_arglist2
      case 147: // two_or_more_arglist
      case 148: // nonempty_arg_pairs
        yylhs.value.build< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
        break;

      case 142: // nonempty_rfparam_arg_list
        yylhs.value.build< std::vector<int> * > ();
        break;

      case 143: // nonempty_noise_device_list
      case 144: // nonempty_voltagenodelist
        yylhs.value.build< std::vector<std::string> * > ();
        break;

      default:
        break;
    }


      // Compute the default @$.
      {
        slice<stack_symbol_type, stack_type> slice (yystack_, yylen);
        YYLLOC_DEFAULT (yylhs.location, slice, yylen);
      }

      // Perform the reduction.
      YY_REDUCE_PRINT (yyn);
      try
        {
          switch (yyn)
            {
  case 2:
#line 781 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yynerrs_ != 0)
      {
        YYABORT;
      }
      else
      {
        newExp.setAstPtr(yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ());

        YYACCEPT;
      }
 }
#line 2506 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 3:
#line 796 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(yystack_[0].value.as< double > ()));
    }
#line 2514 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 4:
#line 800 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(std::complex<basicType>(0.0,yystack_[0].value.as< double > ())));
    }
#line 2522 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 5:
#line 805 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
        createParamOp(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > (),newExp,*yystack_[0].value.as< std::string * > ());
        delete yystack_[0].value.as< std::string * > ();
    }
#line 2531 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 6:
#line 810 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = newExp.getDtNode();
      newExp.setTimeDependent(true);
    }
#line 2540 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 7:
#line 815 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      /*Teuchos::RCP<astNode<usedType> > timeNode = newExp.getTimeNode();
      $$ = Teuchos::RCP<astNode<usedType> >(timeNode); */
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = newExp.getTimeNode();
      newExp.setTimeDependent(true);
    }
#line 2551 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 8:
#line 822 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      /* Teuchos::RCP<astNode<usedType> > tempNode =newExp.getTempNode ();
      $$ = Teuchos::RCP<astNode<usedType> >(tempNode); */
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = newExp.getTempNode ();
      newExp.setTempDependent(true);
    }
#line 2562 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 9:
#line 829 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      /* Teuchos::RCP<astNode<usedType> > vtNode = newExp.getVtNode ();
      $$ = Teuchos::RCP<astNode<usedType> >(vtNode); */
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = newExp.getVtNode ();
      newExp.setVTDependent(true);
    }
#line 2573 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 10:
#line 836 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      /* Teuchos::RCP<astNode<usedType> > freqNode = newExp.getFreqNode ();
      $$ = Teuchos::RCP<astNode<usedType> >(freqNode); */
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = newExp.getFreqNode ();
      newExp.setFreqDependent(true);
    }
#line 2584 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 11:
#line 843 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      /* Teuchos::RCP<astNode<usedType> > gminNode = newExp.getGminNode ();
      $$ = Teuchos::RCP<astNode<usedType> >(gminNode); */
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = newExp.getGminNode ();
      newExp.setGminDependent(true);
    }
#line 2595 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 12:
#line 850 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      /* Teuchos::RCP<astNode<usedType> > piNode = newExp.getPiNode ();
      $$ = Teuchos::RCP<astNode<usedType> >(piNode);*/
      /* $$ = newExp.getPiNode (); */
      usedType pi=M_PI;
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(pi));
    }
#line 2607 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 13:
#line 858 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      /*Teuchos::RCP<astNode<usedType> > CtoKNode = newExp.getCtoKNode ();
      $$ = Teuchos::RCP<astNode<usedType> >(CtoKNode);*/
      /* $$ = newExp.getCtoKNode (); */
      usedType C_to_K = CONSTCtoK;
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(C_to_K));
    }
#line 2619 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 14:
#line 866 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType() && yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val())+(yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new binaryAddOp<usedType>  (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 2633 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 15:
#line 876 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType() && yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val())-(yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new binaryMinusOp<usedType>  (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 2647 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 16:
#line 886 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType() && yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val())*(yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new binaryMulOp<usedType>  (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 2661 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 17:
#line 896 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType() && yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val())/(yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new binaryDivOp<usedType>  (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 2675 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 18:
#line 906 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new fmodOp<usedType>  (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 2683 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 19:
#line 910 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new fmodOp<usedType>  (yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 2691 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 20:
#line 915 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType() && yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType ret =  std::pow(yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val(), yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(ret);  Xyce::Util::fixInf(ret);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(ret));
      }
      else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new powOp<usedType>  (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 2705 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 21:
#line 925 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType() && yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType ret =  std::pow(yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val(), yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(ret);  Xyce::Util::fixInf(ret);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(ret));
      }
      else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new powOp<usedType>  (yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 2719 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 22:
#line 935 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType() && yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType ret =  0.0;
        usedType leftVal=yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val();
        if (std::real(leftVal) >= 0) { ret = std::pow(leftVal, yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val()); }
        else if (std::real(leftVal) < 0) { ret = -std::pow(-(leftVal), yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val()); }
        Xyce::Util::fixNan(ret);  Xyce::Util::fixInf(ret);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(ret));
      }
      else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new pwrsOp<usedType>  (yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 2736 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 23:
#line 948 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
       yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ();
    }
#line 2744 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 24:
#line 952 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
       yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ();
    }
#line 2752 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 25:
#line 956 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(-(yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val()))); }
      else
      { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new unaryMinusOp<usedType>(yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 2763 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 26:
#line 963 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(+(yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val()))); }
      else
      { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new unaryPlusOp<usedType>(yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 2774 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 27:
#line 970 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      { 
        usedType ret = 0.0;
        double leftVal = std::real(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        ret = ( (leftVal>0)?+1:ret );
        ret = ( (leftVal<0)?-1:ret );
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(ret));
      }
      else
      { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new sgnOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 2791 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 28:
#line 983 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType() && yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType y = 0.0;
        double realRightVal = std::real(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        y = ( (realRightVal>0)?+1:y );
        y = ( (realRightVal<0)?-1:y );
        usedType x =  (std::abs(yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val()));
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>((y*x))); 
      }
      else
      { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new signOp<usedType>(yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 2809 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 29:
#line 997 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
        // remove whitespace from the function name
        std::string & functionName = (*yystack_[1].value.as< std::string * > ());

        Teuchos::RCP<funcOp<usedType> > funcPtr = Teuchos::rcp(new funcOp<usedType>(functionName,*yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()));
        newExp.getFuncOpVec().push_back(funcPtr);

        std::unordered_map<std::string,std::vector<Teuchos::RCP<astNode<usedType> > > > & funcOpMap 
          = newExp.getFuncOpMap();

        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(funcPtr); // implicit cast

        if (funcOpMap.find(functionName) == funcOpMap.end())
        {
          std::vector<Teuchos::RCP<astNode<usedType> > > vec;//(1,tmpPtr2);
          vec.push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
          funcOpMap[functionName] = vec;
          newExp.getFuncNameVec().push_back(functionName);
        }
        else
        {
          funcOpMap[functionName].push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
        }

        delete yystack_[1].value.as< std::string * > ();
        delete yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
    }
#line 2841 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 30:
#line 1025 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      createVoltageOp(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > (),newExp,*yystack_[1].value.as< std::string * > (),*yystack_[0].value.as< std::vector<std::string> * > ());
      delete yystack_[1].value.as< std::string * > ();
      delete yystack_[0].value.as< std::vector<std::string> * > ();
    }
#line 2851 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 31:
#line 1031 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      createCurrentOp(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > (),newExp,*yystack_[1].value.as< std::string * > (),*yystack_[0].value.as< std::string * > ());
      delete yystack_[1].value.as< std::string * > ();
      delete yystack_[0].value.as< std::string * > ();
    }
#line 2861 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 32:
#line 1037 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      std::string & firstArg = (*yystack_[1].value.as< std::string * > ());

      Teuchos::RCP<astNode<usedType> > tmpPtr;
      if ((*yystack_[0].value.as< std::vector<int> * > ()).size() == 2)
      {
        if (firstArg[0] == 'S')
        {
          Teuchos::RCP<sparamOp<usedType> > sparPtr = Teuchos::RCP<sparamOp<usedType> >(new sparamOp<usedType>(*yystack_[0].value.as< std::vector<int> * > ()));
          tmpPtr = Teuchos::RCP<astNode<usedType> >(sparPtr);
          newExp.getSparamOpVec ().push_back(sparPtr);
        }
        else if (firstArg[0] == 'Y')
        {
          Teuchos::RCP<yparamOp<usedType> > yparPtr = Teuchos::RCP<yparamOp<usedType> >(new yparamOp<usedType>(*yystack_[0].value.as< std::vector<int> * > ()));
          tmpPtr = Teuchos::RCP<astNode<usedType> >(yparPtr);
          newExp.getYparamOpVec ().push_back(yparPtr);
        }
        else if (firstArg[0] == 'Z')
        {
          Teuchos::RCP<zparamOp<usedType> > zparPtr = Teuchos::RCP<zparamOp<usedType> >(new zparamOp<usedType>(*yystack_[0].value.as< std::vector<int> * > ()));
          tmpPtr = Teuchos::RCP<astNode<usedType> >(zparPtr);
          newExp.getZparamOpVec ().push_back(zparPtr);
        }
        else
        {
          std::cout << "Unrecognized RF parameter: " << firstArg <<std::endl;
        }


        // adjust for complex number variants
        // remove whitespace from the first argument
        if (firstArg.size() == 1)
        {
          yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = tmpPtr;
        }
        else if (firstArg.size() == 2)
        {
           if ( firstArg[1] == 'R')
           {
             yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new realOp<usedType>(tmpPtr));
           }
           else if ( firstArg[1] == 'I')
           {
             yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new imagOp<usedType>(tmpPtr));
           }
           else if ( firstArg[1] == 'M')
           {
             yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new absOp<usedType>(tmpPtr));
           }
           else if ( firstArg[1] == 'P')
           {
            Teuchos::RCP<astNode<usedType> > returnPtr = Teuchos::RCP<astNode<usedType> >(new phaseOp<usedType>(tmpPtr));
             newExp.getPhaseOpVec().push_back(returnPtr);
             yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = returnPtr;
           }
        }
        else if (firstArg.size() == 3) // do decibels here
        {
          if ( firstArg[1] == 'D' && firstArg[2] == 'B')
          {
            // this needs to implement 20.0*std::log10(abs(tmpPtr))  
            Teuchos::RCP<astNode<usedType> > numvalPtr = Teuchos::RCP<astNode<usedType> >(new numval<usedType> (20.0));
            Teuchos::RCP<astNode<usedType> > absPtr = Teuchos::RCP<astNode<usedType> >(new absOp<usedType>(tmpPtr));
            Teuchos::RCP<astNode<usedType> > log10Ptr = Teuchos::RCP<astNode<usedType> >(new log10Op<usedType>(absPtr));
            yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new binaryMulOp<usedType>  (numvalPtr,log10Ptr));
          }
        }
        else
        {
          std::cout << "Unrecognized RF operator " << firstArg << std::endl;
        }
      }
      else
      {
        std::cout << "Wrong number of arguments to S-parameter !" <<std::endl;
      }

      delete yystack_[1].value.as< std::string * > ();
      delete yystack_[0].value.as< std::vector<int> * > ();
    }
#line 2947 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 33:
#line 1119 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<leadCurrentOp<usedType> > leadCurrentPtr = Teuchos::RCP<leadCurrentOp<usedType> >(new leadCurrentOp<usedType>(*yystack_[1].value.as< std::string * > (),*yystack_[0].value.as< std::string * > ()));
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(leadCurrentPtr);
      newExp.getLeadCurrentOpVec().push_back(leadCurrentPtr);

      std::vector<std::string> & leadCurrentNameVec = newExp.getLeadCurrentNameVec();
      std::vector<std::string> & leadCurrentExcludeBsrcNameVec = newExp.getLeadCurrentExcludeBsrcNameVec();
      std::vector<std::string>::iterator nameIter = std::find(leadCurrentNameVec.begin(),leadCurrentNameVec.end(), *yystack_[0].value.as< std::string * > ());
      if ( nameIter == leadCurrentNameVec.end() )
      {
        leadCurrentNameVec.push_back(*yystack_[0].value.as< std::string * > ());
        leadCurrentExcludeBsrcNameVec.push_back(*yystack_[0].value.as< std::string * > ());
      }

      delete yystack_[1].value.as< std::string * > ();
      delete yystack_[0].value.as< std::string * > ();
    }
#line 2969 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 34:
#line 1137 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      const std::string & name=*yystack_[0].value.as< std::string * > ();
      Teuchos::RCP<internalDevVarOp<usedType> > internalDevVarPtr = Teuchos::RCP<internalDevVarOp<usedType> >(new internalDevVarOp<usedType>(name));
      Teuchos::RCP<astNode<usedType> > tmpPtr = Teuchos::RCP<astNode<usedType> >(internalDevVarPtr);
      newExp.getInternalDevVarOpVec().push_back(internalDevVarPtr);

      // adjust for complex number variants
      std::string & firstArg = (*yystack_[1].value.as< std::string * > ());
      if (firstArg.size() == 1)
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = tmpPtr;
      }
      else if (firstArg.size() == 2)
      {
         if ( firstArg == std::string("NR") )
         {
           yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new realOp<usedType>(tmpPtr));
         }
         else if ( firstArg == std::string("NI") )
         {
           yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new imagOp<usedType>(tmpPtr));
         }
         else if ( firstArg == std::string("NM") )
         {
           yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new absOp<usedType>(tmpPtr));
         }
         else if ( firstArg == std::string("NP") )
         {
          Teuchos::RCP<astNode<usedType> > returnPtr = Teuchos::RCP<astNode<usedType> >(new phaseOp<usedType>(tmpPtr));
           newExp.getPhaseOpVec().push_back(returnPtr);
           yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = returnPtr;
         }
      }
      else if (firstArg.size() == 3) // do decibels here
      {
        if ( firstArg == std::string("NDB") )
        {
          // this needs to implement 20.0*std::log10(abs(tmpPtr))  
          Teuchos::RCP<astNode<usedType> > numvalPtr = Teuchos::RCP<astNode<usedType> >(new numval<usedType> (20.0));
          Teuchos::RCP<astNode<usedType> > absPtr = Teuchos::RCP<astNode<usedType> >(new absOp<usedType>(tmpPtr));
          Teuchos::RCP<astNode<usedType> > log10Ptr = Teuchos::RCP<astNode<usedType> >(new log10Op<usedType>(absPtr));
          yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new binaryMulOp<usedType>  (numvalPtr,log10Ptr));
        }
      }
      else
      {
        std::cout << "Unrecognized internal variable operator " << firstArg << std::endl;
      }

      delete yystack_[1].value.as< std::string * > ();
      delete yystack_[0].value.as< std::string * > ();
    }
#line 3026 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 35:
#line 1190 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      std::string & firstArg = (*yystack_[1].value.as< std::string * > ());

      if ( firstArg == std::string("DNO") )
      {
        Teuchos::RCP<dnoNoiseVarOp<usedType> > dnoNoiseVarPtr = Teuchos::RCP<dnoNoiseVarOp<usedType> >(new dnoNoiseVarOp<usedType>(*yystack_[0].value.as< std::vector<std::string> * > ()));
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(dnoNoiseVarPtr);
        newExp.getDnoNoiseDevVarOpVec().push_back(dnoNoiseVarPtr);
      }
      else if ( firstArg == std::string("DNI") )
      {
        Teuchos::RCP<dniNoiseVarOp<usedType> > dniNoiseVarPtr = Teuchos::RCP<dniNoiseVarOp<usedType> >(new dniNoiseVarOp<usedType>(*yystack_[0].value.as< std::vector<std::string> * > ()));
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(dniNoiseVarPtr);
        newExp.getDniNoiseDevVarOpVec().push_back(dniNoiseVarPtr);
      }

      delete yystack_[1].value.as< std::string * > ();
      delete yystack_[0].value.as< std::vector<std::string> * > ();
    }
#line 3050 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 36:
#line 1210 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<oNoiseOp<usedType> > onoisePtr = Teuchos::RCP<oNoiseOp<usedType> >(new oNoiseOp<usedType>());
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(onoisePtr);
      newExp.getONoiseOpVec().push_back(onoisePtr);
      delete yystack_[0].value.as< std::string * > ();
    }
#line 3061 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 37:
#line 1217 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<iNoiseOp<usedType> > inoisePtr = Teuchos::RCP<iNoiseOp<usedType> >(new iNoiseOp<usedType>());
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(inoisePtr);
      newExp.getINoiseOpVec().push_back(inoisePtr);
      delete yystack_[0].value.as< std::string * > ();
    }
#line 3072 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 38:
#line 1224 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new maxOp<usedType>(yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3080 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 39:
#line 1228 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new minOp<usedType>(yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3088 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 40:
#line 1232 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<powerOp<usedType> > powerPtr = Teuchos::RCP<powerOp<usedType> >(new powerOp<usedType>(*yystack_[1].value.as< std::string * > (),*yystack_[0].value.as< std::string * > ()));
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(powerPtr);
      newExp.getPowerOpVec().push_back(powerPtr);

      std::vector<std::string> & leadCurrentNameVec = newExp.getLeadCurrentNameVec();
      std::vector<std::string> & leadCurrentExcludeBsrcNameVec = newExp.getLeadCurrentExcludeBsrcNameVec();
      std::vector<std::string>::iterator nameIter = std::find(leadCurrentNameVec.begin(),leadCurrentNameVec.end(), *yystack_[0].value.as< std::string * > ());
      if ( nameIter == leadCurrentNameVec.end() )
      {
        leadCurrentNameVec.push_back(*yystack_[0].value.as< std::string * > ());
        leadCurrentExcludeBsrcNameVec.push_back(*yystack_[0].value.as< std::string * > ());
      }
      delete yystack_[1].value.as< std::string * > ();
      delete yystack_[0].value.as< std::string * > ();
    }
#line 3109 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 41:
#line 1249 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new phaseOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      newExp.getPhaseOpVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
    }
#line 3118 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 42:
#line 1254 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new realOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3126 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 43:
#line 1258 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new imagOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3134 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 44:
#line 1262 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<astNode<usedType> > numvalPtr = Teuchos::RCP<astNode<usedType> >(new numval<usedType> (20.0));
      Teuchos::RCP<astNode<usedType> > absPtr = Teuchos::RCP<astNode<usedType> >(new absOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      Teuchos::RCP<astNode<usedType> > log10Ptr = Teuchos::RCP<astNode<usedType> >(new log10Op<usedType>(absPtr));
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new binaryMulOp<usedType>  (numvalPtr,log10Ptr));
    }
#line 3145 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 45:
#line 1269 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::sqrt(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new sqrtOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3162 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 46:
#line 1282 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::exp(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new expOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3179 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 47:
#line 1295 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<astNode<usedType> > onePtr = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(1.0));
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new expOp<usedType>(onePtr));
    }
#line 3188 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 48:
#line 1300 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::sin(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new sinOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3205 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 49:
#line 1313 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::cos(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new cosOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3222 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 50:
#line 1326 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::abs(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new absOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3239 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 51:
#line 1339 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::abs(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new absOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3256 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 52:
#line 1352 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::acos(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new acosOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3273 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 53:
#line 1365 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::acosh(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new acoshOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3290 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 54:
#line 1378 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::asin(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new asinOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3307 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 55:
#line 1391 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::asinh(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new asinhOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3324 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 56:
#line 1404 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new atan2Op<usedType>(yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3332 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 57:
#line 1408 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::atan(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new atanOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3349 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 58:
#line 1421 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::atanh(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new atanhOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3366 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 59:
#line 1434 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::cosh(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new coshOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3383 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 60:
#line 1447 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::log(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new logOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3400 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 61:
#line 1460 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (Xyce::Util::useHspiceMath)
      {
        if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
        {
          usedType tmp = std::log(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
          Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
          yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
        }
        else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new logOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
      }
      else
      {
        if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
        {
          usedType tmp = std::log10(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
          Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
          yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
        }
        else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new log10Op<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
      }
    }
#line 3427 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 62:
#line 1483 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::log10(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new log10Op<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 3441 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 63:
#line 1493 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::sinh(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new sinhOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 3455 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 64:
#line 1503 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::tan(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new tanOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 3469 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 65:
#line 1513 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->numvalType())
      {
        usedType tmp = std::tanh(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()->val());
        Xyce::Util::fixNan(tmp);  Xyce::Util::fixInf(tmp);
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(tmp));
      }
      else { yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new tanhOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
    }
#line 3483 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 66:
#line 1523 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new roundOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3491 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 67:
#line 1527 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new ceilOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3499 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 68:
#line 1531 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new floorOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3507 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 69:
#line 1535 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new intOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3515 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 70:
#line 1539 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new twoArgLimitOp<usedType>(yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      newExp.getTwoArgLimitOpVec ().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
      newExp.getLocalTwoArgLimitOpVec ().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
    }
#line 3525 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 71:
#line 1545 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new limitOp<usedType>(yystack_[5].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3533 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 72:
#line 1549 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new stpOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      newExp.getStpNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
    }
#line 3542 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 73:
#line 1554 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new urampOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3550 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 74:
#line 1558 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      // the "pair" contains both the POLYSIZE value as well as a vector of ast nodes (the "args")
      // $1->first  - numvars
      // $1->second - vars and coefs
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = setupPoly (newExp,yystack_[0].value.as< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > ()->first, (yystack_[0].value.as< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > ()->second));
      delete yystack_[0].value.as< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > ();
    }
#line 3562 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 75:
#line 1566 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<astNode<usedType> > timeNode = newExp.getTimeNode();
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new tableOp<usedType>(*(yystack_[2].value.as< std::string * > ()),timeNode,*yystack_[1].value.as< std::string * > ())); 
      newExp.getSrcNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
      newExp.setTimeDependent(true); 
      delete yystack_[1].value.as< std::string * > ();
    }
#line 3574 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 76:
#line 1576 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new tableOp<usedType>(*(yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().keywordPtr), yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().node,*yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ())); 
      if ( (yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().node)->timeSpecialType() )
      {
        newExp.getSrcNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
        newExp.setTimeDependent(true); 
      }
      delete yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
      delete yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().keywordPtr;
    }
#line 3589 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 77:
#line 1587 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new tableOp<usedType>(*(yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().keywordPtr), yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().node,*yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()));
      if ( (yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().node)->timeSpecialType() )
      {
        newExp.getSrcNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
        newExp.setTimeDependent(true); 
      }
      delete yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
      delete yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().keywordPtr;
    }
#line 3604 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 78:
#line 1598 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new tableOp<usedType>(*(yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().keywordPtr), yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().node,*yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()));
      if ( (yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().node)->timeSpecialType() )
      {
        newExp.getSrcNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
        newExp.setTimeDependent(true); 
      }
      delete yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
      delete yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().keywordPtr;
    }
#line 3619 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 79:
#line 1609 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new tableOp<usedType>(*(yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().keywordPtr), yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().node,*yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()));
      if ( (yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().node)->timeSpecialType() )
      {
        newExp.getSrcNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
        newExp.setTimeDependent(true); 
      }
      delete yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
      delete yystack_[1].value.as< Xyce::Util::tableArgs<usedType>  > ().keywordPtr;
    }
#line 3634 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 80:
#line 1636 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<astNode<usedType> > timeNode = newExp.getTimeNode();
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new scheduleOp<usedType>(*yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > (), timeNode));
      newExp.getSrcNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
      newExp.setTimeDependent(true);
      delete yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
    }
#line 3646 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 81:
#line 1644 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<astNode<usedType> > timeNode = newExp.getTimeNode();
      Teuchos::RCP<astNode<usedType> > dtNode = newExp.getDtNode();
      Teuchos::RCP<astNode<usedType> > sdtPtr = Teuchos::RCP<astNode<usedType> >(new sdtOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > (), dtNode, timeNode));
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = sdtPtr;
      newExp.getSdtOpVec().push_back(sdtPtr);
      newExp.getLocalSdtOpVec().push_back(sdtPtr);
      newExp.setTimeDependent(true);
    }
#line 3660 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 82:
#line 1654 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<astNode<usedType> > timeNode = newExp.getTimeNode();
      Teuchos::RCP<astNode<usedType> > dtNode = newExp.getDtNode();
      Teuchos::RCP<astNode<usedType> > ddtPtr = Teuchos::RCP<astNode<usedType> >(new ddtOp<usedType>(yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > (), dtNode, timeNode));
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = ddtPtr;
      newExp.getDdtOpVec().push_back(ddtPtr);
      newExp.getLocalDdtOpVec().push_back(ddtPtr);
      newExp.setTimeDependent(true);
    }
#line 3674 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 83:
#line 1664 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new ddxOp<usedType>(yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3682 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 84:
#line 1668 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<agaussOp<usedType> > agaussPtr = Teuchos::RCP<agaussOp<usedType> >(new agaussOp<usedType> (yystack_[5].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(agaussPtr);
      newExp.getAgaussOpVec ().push_back(agaussPtr);
      newExp.getLocalAgaussOpVec ().push_back(agaussPtr);
    }
#line 3693 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 85:
#line 1675 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<gaussOp<usedType> > gaussPtr = Teuchos::RCP<gaussOp<usedType> >(new gaussOp<usedType>(yystack_[5].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(gaussPtr);
      newExp.getGaussOpVec ().push_back(gaussPtr);
      newExp.getLocalGaussOpVec ().push_back(gaussPtr);
    }
#line 3704 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 86:
#line 1682 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<aunifOp<usedType> > aunifPtr = Teuchos::RCP<aunifOp<usedType> >(new aunifOp<usedType>(yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(aunifPtr);
      newExp.getAunifOpVec ().push_back(aunifPtr);
      newExp.getLocalAunifOpVec ().push_back(aunifPtr);
    }
#line 3715 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 87:
#line 1689 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<unifOp<usedType> > unifPtr = Teuchos::RCP<unifOp<usedType> >(new unifOp<usedType>(yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(unifPtr);
      newExp.getUnifOpVec ().push_back(unifPtr);
      newExp.getLocalUnifOpVec ().push_back(unifPtr);
    }
#line 3726 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 88:
#line 1696 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<randOp<usedType> > randPtr = Teuchos::RCP<randOp<usedType> >(new randOp<usedType>());
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(randPtr);
      newExp.getRandOpVec ().push_back(randPtr);
      newExp.getLocalRandOpVec ().push_back(randPtr);
    }
#line 3737 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 89:
#line 1706 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<astNode<usedType> > timeNode = newExp.getTimeNode();
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new spicePulseOp<usedType>(*yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > (), timeNode ));
      newExp.getSrcNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
      newExp.setTimeDependent(true);
      delete yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
    }
#line 3749 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 90:
#line 1715 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<astNode<usedType> > timeNode = newExp.getTimeNode();
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new spiceSinOp<usedType>(*yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > (), timeNode ));
      newExp.getSrcNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
      newExp.setTimeDependent(true);
      delete yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
    }
#line 3761 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 91:
#line 1724 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<astNode<usedType> > timeNode = newExp.getTimeNode();
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new spiceExpOp<usedType>(*yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > (),timeNode));
      newExp.getSrcNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
      newExp.setTimeDependent(true);
      delete yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
    }
#line 3773 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 92:
#line 1733 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Teuchos::RCP<astNode<usedType> > timeNode = newExp.getTimeNode();
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new spiceSffmOp<usedType>(*yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > (),timeNode));
      newExp.setTimeDependent(true);
      delete yystack_[0].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();
    }
#line 3784 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 93:
#line 1740 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new ifStatementOp<usedType>(yystack_[4].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3792 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 94:
#line 1744 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new ifStatementOp<usedType>(yystack_[5].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3800 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 95:
#line 1748 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new eqOp<usedType>(yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      newExp.getCompNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
    }
#line 3809 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 96:
#line 1753 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new neOp<usedType>(yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      newExp.getCompNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
    }
#line 3818 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 97:
#line 1758 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new gtOp<usedType>(yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      newExp.getCompNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
    }
#line 3827 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 98:
#line 1763 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new ltOp<usedType>(yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      newExp.getCompNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
    }
#line 3836 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 99:
#line 1768 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ()  = Teuchos::RCP<astNode<usedType> >(new geOp<usedType>(yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      newExp.getCompNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
    }
#line 3845 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 100:
#line 1773 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new leOp<usedType>(yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      newExp.getCompNodeVec().push_back(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > ());
    }
#line 3854 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 101:
#line 1778 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new orOp<usedType>(yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3862 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 102:
#line 1782 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new andOp<usedType>(yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3870 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 103:
#line 1786 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      if (Xyce::Util::useHspiceMath)
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new powOp<usedType>  (yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
      else
      {
        yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new xorOp<usedType>(yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > (),yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
      }
    }
#line 3885 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 104:
#line 1797 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new unaryNotOp<usedType>(yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()));
    }
#line 3893 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 105:
#line 1802 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Xyce::Report::UserError() << "Syntax error in number of nodes in expression: " << newExp.getExpressionString() << std::endl;

      // the "rand" operator is allocated here b/c all of these functions need to return a 
      // valid operator or else cause a segfault.  It is not intended to be used, as this function
      // is trapping for an error condition.  randOp is a convenient
      // choice b/c it doens't require any arguments.
      Teuchos::RCP<randOp<usedType> > randPtr = Teuchos::RCP<randOp<usedType> >(new randOp<usedType>());
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(randPtr);
    }
#line 3908 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 106:
#line 1813 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Xyce::Report::UserError() << "Invalid operator in expression " << newExp.getExpressionString() << std::endl;

      // the "rand" operator is allocated here b/c all of these functions need to return a 
      // valid operator or else cause a segfault.  It is not intended to be used, as this function
      // is trapping for an error condition.  randOp is a convenient
      // choice b/c it doens't require any arguments.
      Teuchos::RCP<randOp<usedType> > randPtr = Teuchos::RCP<randOp<usedType> >(new randOp<usedType>());
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(randPtr);
    }
#line 3923 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 107:
#line 1825 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yylhs.value.as< std::vector<int> * > () = new std::vector<int>(1,yystack_[0].value.as< int > ()); }
#line 3929 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 108:
#line 1826 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yystack_[1].value.as< std::vector<int> * > ()->push_back(yystack_[0].value.as< int > ()); yylhs.value.as< std::vector<int> * > ()=yystack_[1].value.as< std::vector<int> * > (); }
#line 3935 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 109:
#line 1828 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yylhs.value.as< std::vector<std::string> * > () = new std::vector< std::string>(1,*yystack_[0].value.as< std::string * > ()); }
#line 3941 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 110:
#line 1829 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yystack_[1].value.as< std::vector<std::string> * > ()->push_back(*yystack_[0].value.as< std::string * > ()); yylhs.value.as< std::vector<std::string> * > () = yystack_[1].value.as< std::vector<std::string> * > (); }
#line 3947 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 111:
#line 1831 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yylhs.value.as< std::vector<std::string> * > () = new std::vector< std::string>(1,*yystack_[0].value.as< std::string * > ()); }
#line 3953 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 112:
#line 1832 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yystack_[1].value.as< std::vector<std::string> * > ()->push_back(*yystack_[0].value.as< std::string * > ()); yylhs.value.as< std::vector<std::string> * > ()=yystack_[1].value.as< std::vector<std::string> * > (); }
#line 3959 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 113:
#line 1834 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yylhs.value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > () = new std::vector< Teuchos::RCP<astNode<usedType> > >(1,yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ());   }
#line 3965 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 114:
#line 1835 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yylhs.value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()=yystack_[1].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();  }
#line 3971 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 115:
#line 1837 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yylhs.value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > () = new std::vector< Teuchos::RCP<astNode<usedType> > >(1,yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ());   }
#line 3977 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 116:
#line 1838 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yylhs.value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()=yystack_[2].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ();  }
#line 3983 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 117:
#line 1840 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yylhs.value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > () = new std::vector< Teuchos::RCP<astNode<usedType> > >(1,yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ()); yylhs.value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()->push_back((yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ())); }
#line 3989 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 118:
#line 1841 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yystack_[2].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()->push_back((yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ())); yylhs.value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()=yystack_[2].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > (); }
#line 3995 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 119:
#line 1843 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yylhs.value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > () = new std::vector< Teuchos::RCP<astNode<usedType> > >(1,yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > ());  yylhs.value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()->push_back((yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ()));  }
#line 4001 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 120:
#line 1844 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yystack_[5].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()->push_back((yystack_[3].value.as< Teuchos::RCP<astNode<usedType> >  > ())); yystack_[5].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()->push_back((yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ())); yylhs.value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > ()=yystack_[5].value.as< std::vector< Teuchos::RCP<astNode<usedType> > > * > (); }
#line 4007 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 121:
#line 1848 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
    std::vector< Teuchos::RCP<astNode<usedType> > > first(1,yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ());
    yylhs.value.as< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > () = new std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > >(yystack_[1].value.as< double > (),first);
  }
#line 4016 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 122:
#line 1852 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    { yystack_[1].value.as< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > ()->second.push_back(yystack_[0].value.as< Teuchos::RCP<astNode<usedType> >  > ()); yylhs.value.as< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > ()=yystack_[1].value.as< std::pair<double, std::vector< Teuchos::RCP<astNode<usedType> > > > * > (); }
#line 4022 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 123:
#line 1856 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      createVoltageOp(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > (),newExp,*yystack_[1].value.as< std::string * > (),*yystack_[0].value.as< std::vector<std::string> * > ());
      delete yystack_[1].value.as< std::string * > ();
      delete yystack_[0].value.as< std::vector<std::string> * > ();
    }
#line 4032 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 124:
#line 1862 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      createCurrentOp(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > (),newExp,*yystack_[1].value.as< std::string * > (),*yystack_[0].value.as< std::string * > ());
      delete yystack_[1].value.as< std::string * > ();
      delete yystack_[0].value.as< std::string * > ();
    }
#line 4042 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 125:
#line 1868 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      createParamOp(yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > (),newExp,*yystack_[0].value.as< std::string * > ());
      delete yystack_[0].value.as< std::string * > ();
    }
#line 4051 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 126:
#line 1873 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      yylhs.value.as< Teuchos::RCP<astNode<usedType> >  > () = Teuchos::RCP<astNode<usedType> >(new numval<usedType>(yystack_[0].value.as< double > ()));
    }
#line 4059 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 127:
#line 1878 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
       yylhs.value.as< double > () = yystack_[0].value.as< double > ();
     }
#line 4067 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 128:
#line 1882 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
       yylhs.value.as< double > () = yystack_[1].value.as< double > ();
    }
#line 4075 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 129:
#line 1886 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
       yylhs.value.as< double > () = yystack_[1].value.as< double > ();
    }
#line 4083 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 130:
#line 1892 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
       yylhs.value.as< std::string * > () = yystack_[0].value.as< std::string * > ();
     }
#line 4091 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 131:
#line 1896 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
       yylhs.value.as< std::string * > () = yystack_[1].value.as< std::string * > ();
    }
#line 4099 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 132:
#line 1900 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
       yylhs.value.as< std::string * > () = yystack_[1].value.as< std::string * > ();
    }
#line 4107 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 133:
#line 1920 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Xyce::Util::tableArgs<usedType> ta;
      ta.keywordPtr = yystack_[2].value.as< std::string * > ();
      ta.node = yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ();
      yylhs.value.as< Xyce::Util::tableArgs<usedType>  > () = ta;
    }
#line 4118 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 134:
#line 1927 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Xyce::Util::tableArgs<usedType> ta;
      ta.keywordPtr = yystack_[3].value.as< std::string * > ();
      ta.node = yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ();
      yylhs.value.as< Xyce::Util::tableArgs<usedType>  > () = ta;
    }
#line 4129 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 135:
#line 1934 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Xyce::Util::tableArgs<usedType> ta;
      ta.keywordPtr = yystack_[2].value.as< std::string * > ();
      ta.node = yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ();
      yylhs.value.as< Xyce::Util::tableArgs<usedType>  > () = ta;
    }
#line 4140 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 136:
#line 1941 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Xyce::Util::tableArgs<usedType> ta;
      ta.keywordPtr = yystack_[3].value.as< std::string * > ();
      ta.node = yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ();
      yylhs.value.as< Xyce::Util::tableArgs<usedType>  > () = ta;
    }
#line 4151 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 137:
#line 1948 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Xyce::Util::tableArgs<usedType> ta;
      ta.keywordPtr = yystack_[2].value.as< std::string * > ();
      ta.node = yystack_[1].value.as< Teuchos::RCP<astNode<usedType> >  > ();
      yylhs.value.as< Xyce::Util::tableArgs<usedType>  > () = ta;
    }
#line 4162 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;

  case 138:
#line 1955 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:859
    {
      Xyce::Util::tableArgs<usedType> ta;
      ta.keywordPtr = yystack_[3].value.as< std::string * > ();
      ta.node = yystack_[2].value.as< Teuchos::RCP<astNode<usedType> >  > ();
      yylhs.value.as< Xyce::Util::tableArgs<usedType>  > () = ta;
    }
#line 4173 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
    break;


#line 4177 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:859
            default:
              break;
            }
        }
      catch (const syntax_error& yyexc)
        {
          error (yyexc);
          YYERROR;
        }
      YY_SYMBOL_PRINT ("-> $$ =", yylhs);
      yypop_ (yylen);
      yylen = 0;
      YY_STACK_PRINT ();

      // Shift the result of the reduction.
      yypush_ (YY_NULLPTR, yylhs);
    }
    goto yynewstate;

  /*--------------------------------------.
  | yyerrlab -- here on detecting error.  |
  `--------------------------------------*/
  yyerrlab:
    // If not already recovering from an error, report this error.
    if (!yyerrstatus_)
      {
        ++yynerrs_;
        error (yyla.location, yysyntax_error_ (yystack_[0].state, yyla));
      }


    yyerror_range[1].location = yyla.location;
    if (yyerrstatus_ == 3)
      {
        /* If just tried and failed to reuse lookahead token after an
           error, discard it.  */

        // Return failure if at end of input.
        if (yyla.type_get () == yyeof_)
          YYABORT;
        else if (!yyla.empty ())
          {
            yy_destroy_ ("Error: discarding", yyla);
            yyla.clear ();
          }
      }

    // Else will try to reuse lookahead token after shifting the error token.
    goto yyerrlab1;


  /*---------------------------------------------------.
  | yyerrorlab -- error raised explicitly by YYERROR.  |
  `---------------------------------------------------*/
  yyerrorlab:

    /* Pacify compilers like GCC when the user code never invokes
       YYERROR and the label yyerrorlab therefore never appears in user
       code.  */
    if (false)
      goto yyerrorlab;
    yyerror_range[1].location = yystack_[yylen - 1].location;
    /* Do not reclaim the symbols of the rule whose action triggered
       this YYERROR.  */
    yypop_ (yylen);
    yylen = 0;
    goto yyerrlab1;

  /*-------------------------------------------------------------.
  | yyerrlab1 -- common code for both syntax error and YYERROR.  |
  `-------------------------------------------------------------*/
  yyerrlab1:
    yyerrstatus_ = 3;   // Each real token shifted decrements this.
    {
      stack_symbol_type error_token;
      for (;;)
        {
          yyn = yypact_[yystack_[0].state];
          if (!yy_pact_value_is_default_ (yyn))
            {
              yyn += yyterror_;
              if (0 <= yyn && yyn <= yylast_ && yycheck_[yyn] == yyterror_)
                {
                  yyn = yytable_[yyn];
                  if (0 < yyn)
                    break;
                }
            }

          // Pop the current state because it cannot handle the error token.
          if (yystack_.size () == 1)
            YYABORT;

          yyerror_range[1].location = yystack_[0].location;
          yy_destroy_ ("Error: popping", yystack_[0]);
          yypop_ ();
          YY_STACK_PRINT ();
        }

      yyerror_range[2].location = yyla.location;
      YYLLOC_DEFAULT (error_token.location, yyerror_range, 2);

      // Shift the error token.
      error_token.state = yyn;
      yypush_ ("Shifting", error_token);
    }
    goto yynewstate;

    // Accept.
  yyacceptlab:
    yyresult = 0;
    goto yyreturn;

    // Abort.
  yyabortlab:
    yyresult = 1;
    goto yyreturn;

  yyreturn:
    if (!yyla.empty ())
      yy_destroy_ ("Cleanup: discarding lookahead", yyla);

    /* Do not reclaim the symbols of the rule whose action triggered
       this YYABORT or YYACCEPT.  */
    yypop_ (yylen);
    while (1 < yystack_.size ())
      {
        yy_destroy_ ("Cleanup: popping", yystack_[0]);
        yypop_ ();
      }

    return yyresult;
  }
    catch (...)
      {
        YYCDEBUG << "Exception caught: cleaning lookahead and stack"
                 << std::endl;
        // Do not try to display the values of the reclaimed symbols,
        // as their printer might throw an exception.
        if (!yyla.empty ())
          yy_destroy_ (YY_NULLPTR, yyla);

        while (1 < yystack_.size ())
          {
            yy_destroy_ (YY_NULLPTR, yystack_[0]);
            yypop_ ();
          }
        throw;
      }
  }

  void
  ExpressionParser::error (const syntax_error& yyexc)
  {
    error (yyexc.location, yyexc.what());
  }

  // Generate an error message.
  std::string
  ExpressionParser::yysyntax_error_ (state_type, const symbol_type&) const
  {
    return YY_("syntax error");
  }


  const signed char ExpressionParser::yypact_ninf_ = -127;

  const signed char ExpressionParser::yytable_ninf_ = -1;

  const short int
  ExpressionParser::yypact_[] =
  {
     584,    56,  -127,  -127,  -127,   584,    -5,  -127,  -127,     9,
      53,    61,    49,    50,    60,   584,   584,   584,    80,   584,
     584,   584,   584,   584,   584,   584,   584,  -127,   584,   584,
     584,   584,   584,   584,   584,   584,   584,   584,   584,   584,
     584,   584,   584,   584,   584,   584,   584,   584,   584,   584,
     584,   584,   584,   584,   584,   584,   584,   584,   584,   584,
      -3,   584,   584,   584,   584,   584,   584,  -127,   584,   584,
     584,   584,  -127,  -127,  -127,  -127,  -127,  -127,  -127,  -127,
     584,   584,   584,   584,   584,   584,    90,  2950,    56,   584,
      -1,   584,  -127,    53,    84,  -127,    -2,    -2,  -127,  -127,
    -127,    -8,  -127,   -85,  -127,  -127,  -127,    83,  -127,  -127,
    -127,    82,  -127,    78,  2362,  2266,  2300,    29,   600,  2390,
    2418,   634,   668,   702,   736,   770,   804,   838,   872,   906,
     940,   974,  1008,  1042,  2446,  1076,  1110,  1144,  1178,  1212,
    1246,  1280,  1314,  1348,  2474,  2502,  2530,  2558,  2586,  1382,
    1416,  2614,  1450,  2642,  1484,  1518,  2670,  2698,  -127,  1552,
    1586,  2726,  1620,  -127,  1654,  -127,  -127,  -127,  -127,  1688,
    2334,   317,   -27,  -126,  2754,  -127,   584,   584,   584,   584,
     584,   584,   584,   584,   584,   584,   584,   584,   584,   584,
     584,   584,   584,  -127,    32,  -127,  -127,   -26,   584,    16,
    -127,    83,  -127,    19,    21,    22,    24,  -127,   584,  -127,
     584,  -127,  -127,  -127,    64,    66,    69,  -127,  -127,   584,
     584,  -127,  -127,  -127,  -127,  -127,  -127,  -127,  -127,  -127,
    -127,  -127,  -127,  -127,   584,  -127,  -127,  -127,  -127,  -127,
    -127,  -127,  -127,  -127,   584,   584,   584,   584,   584,  -127,
    -127,   584,  -127,   584,  -127,  -127,   584,   584,  -127,  -127,
     584,  -127,  -127,  -127,  -127,   584,  2922,   317,   317,   441,
      79,    79,    79,    79,    79,    79,  -125,  -126,  -126,   -67,
     -27,   -27,   -27,   324,   454,  2782,   584,  -127,  -127,  -127,
    -127,  2950,  2950,  -127,  -127,  -127,  1722,  1756,  1790,  2810,
    1824,  1858,  2838,  1892,  2866,  1926,   174,  1960,  1994,  2028,
     584,  -127,  -127,   584,  2894,  -127,  -127,  -127,   584,  -127,
    -127,   584,  -127,   584,  -127,  -127,   584,  -127,  -127,  -127,
    2950,  2062,   584,  2096,  2130,  2164,  2198,  -127,  2232,  -127,
    -127,  -127,  -127,  -127
  };

  const unsigned char
  ExpressionParser::yydefact_[] =
  {
       0,     0,     3,     4,     5,     0,     0,    36,    37,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,    47,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,   105,     0,     0,
       0,     0,     6,     7,     8,     9,    10,    11,    12,    13,
       0,     0,     0,     0,     0,     0,     0,     2,    74,     0,
       0,     0,   127,     0,     0,   130,     0,     0,   121,   126,
     125,     0,    29,     0,    33,    40,   111,    30,    31,    34,
     109,    35,   107,    32,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,    88,     0,
       0,     0,     0,    80,     0,    89,    90,    91,    92,     0,
       0,   104,    25,    26,     0,     1,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,   122,     0,    77,    78,     0,     0,    79,
      76,   123,   124,     0,     0,     0,     0,   113,     0,   114,
       0,   112,   110,   108,   133,   135,   137,    75,    45,     0,
       0,    41,    42,    43,    44,    46,    48,    49,    50,    51,
      52,    53,    54,    55,     0,    57,    58,    59,    60,    61,
      62,    63,    64,    65,     0,     0,     0,     0,     0,    66,
      67,     0,    82,     0,    68,    69,     0,     0,    81,    27,
       0,    72,    73,    23,    24,     0,     0,   101,   102,   103,
      95,    96,   100,    98,    99,    97,   106,    15,    14,    18,
      16,    17,    20,     0,     0,     0,     0,   128,   131,   129,
     132,   117,   118,   134,   136,   138,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,   115,   116,     0,     0,    38,    39,    56,     0,    86,
      87,     0,    19,     0,    83,    70,     0,    22,    28,    21,
      93,     0,     0,     0,     0,     0,     0,   119,     0,    94,
      84,    85,    71,   120
  };

  const short int
  ExpressionParser::yypgoto_[] =
  {
    -127,  -127,     0,  -127,  -127,    37,   132,  -127,    43,  -127,
    -127,    46,   -19,     4,  -127,  -127,  -127
  };

  const short int
  ExpressionParser::yydefgoto_[] =
  {
      -1,    86,   101,   113,   111,   107,   102,   196,   103,   199,
      88,    98,    99,   100,    89,    90,    91
  };

  const unsigned short int
  ExpressionParser::yytable_[] =
  {
      87,   187,    92,   188,   189,   189,   190,   190,   191,   191,
     209,   192,   192,   104,   210,   114,   115,   116,    95,   118,
     119,   120,   121,   122,   123,   124,   125,   105,   126,   127,
     128,   129,   130,   131,   132,   133,   134,   135,   136,   137,
     138,   139,   140,   141,   142,   143,   144,   145,   146,   147,
     148,   149,   150,   151,   152,   153,   154,   155,   156,   157,
      92,   159,   160,   161,   162,   190,   164,   191,   106,   209,
     192,   109,    93,   284,   110,    94,    95,   203,   205,   108,
     169,   170,   171,   172,   173,   174,   112,   207,   117,   194,
     175,   208,   158,   176,    96,   198,    97,   177,   211,   178,
     204,   206,   202,   179,   213,   180,   212,   181,   217,   182,
     192,   183,   286,   184,   287,   185,   288,   186,   187,   289,
     188,   290,   189,   293,   190,   294,   191,   207,   295,   192,
     201,   283,   197,   176,   193,     0,     0,   177,     0,   178,
       0,     0,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,    96,   184,    97,   185,     0,   186,   187,     0,
     188,     0,   189,     0,   190,     0,   191,     0,     0,   192,
       0,     0,     0,     0,     0,     0,   266,   267,   268,   269,
     270,   271,   272,   273,   274,   275,   276,   277,   278,   279,
     280,   281,   282,     0,     0,     0,     0,   163,   285,     0,
     165,   166,   167,   168,   186,   187,     0,   188,   291,   189,
     292,   190,     0,   191,     0,     0,   192,     0,     0,   296,
     297,   195,     0,   200,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,   298,     0,     0,     0,     0,     0,
       0,     0,     0,     0,   299,   300,   301,   302,   303,     0,
       0,   304,     0,   305,     0,     0,   306,   307,     0,     0,
     308,     0,     0,     0,     0,   309,     0,     0,     0,   325,
       0,     0,     0,   326,     0,   176,     0,     0,     0,   177,
       0,   178,     0,   291,   292,   179,   314,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,     0,   189,     0,   190,     0,   191,     0,
     330,   192,     0,   331,     0,     0,     0,     0,   333,     0,
       0,   334,     0,   335,     0,     0,   336,     1,     0,     2,
       3,     4,   338,     5,     6,     7,     8,     9,    10,     0,
       0,    11,     0,     0,     0,    12,     0,    13,     0,    14,
       0,    15,    16,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    35,    36,    37,    38,    39,    40,    41,    42,    43,
      44,    45,    46,     0,     0,    47,    48,    49,    50,    51,
      52,    53,    54,    55,    56,    57,    58,    59,    60,    61,
      62,    63,    64,     0,    65,    66,    67,    68,    69,    70,
      71,    72,    73,    74,    75,    76,    77,    78,    79,   311,
      80,     0,    81,     0,     0,     0,     0,     0,   179,     0,
     180,     0,   181,    82,   182,     0,   183,     0,   184,     0,
     185,     0,   186,   187,     0,   188,     0,   189,     0,   190,
      83,   191,    84,     0,   192,     0,     0,     1,     0,     2,
       3,     4,    85,     5,     6,     7,     8,     9,    10,     0,
       0,    11,     0,     0,     0,    12,     0,    13,     0,    14,
       0,    15,    16,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    35,    36,    37,    38,    39,    40,    41,    42,    43,
      44,    45,    46,     0,     0,    47,    48,    49,    50,    51,
      52,    53,    54,    55,    56,    57,    58,    59,    60,    61,
      62,    63,    64,     0,    65,    66,    67,    68,    69,    70,
      71,    72,    73,    74,    75,    76,    77,    78,    79,   312,
      80,     0,    81,     0,   180,     0,   181,     0,   182,     0,
     183,     0,   184,    82,   185,     0,   186,   187,     0,   188,
       0,   189,     0,   190,     0,   191,     0,     0,   192,     0,
      83,     0,    84,     0,     0,     0,     0,     1,     0,     2,
       3,     4,    85,     5,     6,     7,     8,     9,    10,     0,
       0,    11,     0,     0,     0,    12,     0,    13,     0,    14,
       0,    15,    16,    17,    18,    19,    20,    21,    22,    23,
      24,    25,    26,    27,    28,    29,    30,    31,    32,    33,
      34,    35,    36,    37,    38,    39,    40,    41,    42,    43,
      44,    45,    46,     0,     0,    47,    48,    49,    50,    51,
      52,    53,    54,    55,    56,    57,    58,    59,    60,    61,
      62,    63,    64,     0,    65,    66,    67,    68,    69,    70,
      71,    72,    73,    74,    75,    76,    77,    78,    79,     0,
      80,     0,    81,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,    82,     0,   218,     0,     0,     0,     0,
       0,   176,     0,     0,     0,   177,     0,   178,     0,     0,
      83,   179,    84,   180,     0,   181,     0,   182,     0,   183,
       0,   184,    85,   185,     0,   186,   187,     0,   188,   221,
     189,     0,   190,     0,   191,   176,     0,   192,     0,   177,
       0,   178,     0,     0,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,   222,   189,     0,   190,     0,   191,   176,
       0,   192,     0,   177,     0,   178,     0,     0,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,     0,   188,   223,   189,     0,
     190,     0,   191,   176,     0,   192,     0,   177,     0,   178,
       0,     0,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,     0,
     188,   224,   189,     0,   190,     0,   191,   176,     0,   192,
       0,   177,     0,   178,     0,     0,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,     0,   188,   225,   189,     0,   190,     0,
     191,   176,     0,   192,     0,   177,     0,   178,     0,     0,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,     0,   188,   226,
     189,     0,   190,     0,   191,   176,     0,   192,     0,   177,
       0,   178,     0,     0,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,   227,   189,     0,   190,     0,   191,   176,
       0,   192,     0,   177,     0,   178,     0,     0,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,     0,   188,   228,   189,     0,
     190,     0,   191,   176,     0,   192,     0,   177,     0,   178,
       0,     0,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,     0,
     188,   229,   189,     0,   190,     0,   191,   176,     0,   192,
       0,   177,     0,   178,     0,     0,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,     0,   188,   230,   189,     0,   190,     0,
     191,   176,     0,   192,     0,   177,     0,   178,     0,     0,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,     0,   188,   231,
     189,     0,   190,     0,   191,   176,     0,   192,     0,   177,
       0,   178,     0,     0,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,   232,   189,     0,   190,     0,   191,   176,
       0,   192,     0,   177,     0,   178,     0,     0,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,     0,   188,   233,   189,     0,
     190,     0,   191,   176,     0,   192,     0,   177,     0,   178,
       0,     0,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,     0,
     188,   235,   189,     0,   190,     0,   191,   176,     0,   192,
       0,   177,     0,   178,     0,     0,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,     0,   188,   236,   189,     0,   190,     0,
     191,   176,     0,   192,     0,   177,     0,   178,     0,     0,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,     0,   188,   237,
     189,     0,   190,     0,   191,   176,     0,   192,     0,   177,
       0,   178,     0,     0,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,   238,   189,     0,   190,     0,   191,   176,
       0,   192,     0,   177,     0,   178,     0,     0,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,     0,   188,   239,   189,     0,
     190,     0,   191,   176,     0,   192,     0,   177,     0,   178,
       0,     0,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,     0,
     188,   240,   189,     0,   190,     0,   191,   176,     0,   192,
       0,   177,     0,   178,     0,     0,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,     0,   188,   241,   189,     0,   190,     0,
     191,   176,     0,   192,     0,   177,     0,   178,     0,     0,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,     0,   188,   242,
     189,     0,   190,     0,   191,   176,     0,   192,     0,   177,
       0,   178,     0,     0,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,   243,   189,     0,   190,     0,   191,   176,
       0,   192,     0,   177,     0,   178,     0,     0,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,     0,   188,   249,   189,     0,
     190,     0,   191,   176,     0,   192,     0,   177,     0,   178,
       0,     0,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,     0,
     188,   250,   189,     0,   190,     0,   191,   176,     0,   192,
       0,   177,     0,   178,     0,     0,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,     0,   188,   252,   189,     0,   190,     0,
     191,   176,     0,   192,     0,   177,     0,   178,     0,     0,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,     0,   188,   254,
     189,     0,   190,     0,   191,   176,     0,   192,     0,   177,
       0,   178,     0,     0,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,   255,   189,     0,   190,     0,   191,   176,
       0,   192,     0,   177,     0,   178,     0,     0,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,     0,   188,   258,   189,     0,
     190,     0,   191,   176,     0,   192,     0,   177,     0,   178,
       0,     0,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,     0,
     188,   259,   189,     0,   190,     0,   191,   176,     0,   192,
       0,   177,     0,   178,     0,     0,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,     0,   188,   261,   189,     0,   190,     0,
     191,   176,     0,   192,     0,   177,     0,   178,     0,     0,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,     0,   188,   262,
     189,     0,   190,     0,   191,   176,     0,   192,     0,   177,
       0,   178,     0,     0,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,   263,   189,     0,   190,     0,   191,   176,
       0,   192,     0,   177,     0,   178,     0,     0,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,     0,   188,   315,   189,     0,
     190,     0,   191,   176,     0,   192,     0,   177,     0,   178,
       0,     0,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,     0,
     188,   316,   189,     0,   190,     0,   191,   176,     0,   192,
       0,   177,     0,   178,     0,     0,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,     0,   188,   317,   189,     0,   190,     0,
     191,   176,     0,   192,     0,   177,     0,   178,     0,     0,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,     0,   188,   319,
     189,     0,   190,     0,   191,   176,     0,   192,     0,   177,
       0,   178,     0,     0,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,   320,   189,     0,   190,     0,   191,   176,
       0,   192,     0,   177,     0,   178,     0,     0,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,     0,   188,   322,   189,     0,
     190,     0,   191,   176,     0,   192,     0,   177,     0,   178,
       0,     0,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,     0,
     188,   324,   189,     0,   190,     0,   191,   176,     0,   192,
       0,   177,     0,   178,     0,     0,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,     0,   188,   327,   189,     0,   190,     0,
     191,   176,     0,   192,     0,   177,     0,   178,     0,     0,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,     0,   188,   328,
     189,     0,   190,     0,   191,   176,     0,   192,     0,   177,
       0,   178,     0,     0,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,   329,   189,     0,   190,     0,   191,   176,
       0,   192,     0,   177,     0,   178,     0,     0,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,     0,   188,   337,   189,     0,
     190,     0,   191,   176,     0,   192,     0,   177,     0,   178,
       0,     0,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,     0,
     188,   339,   189,     0,   190,     0,   191,   176,     0,   192,
       0,   177,     0,   178,     0,     0,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,     0,   188,   340,   189,     0,   190,     0,
     191,   176,     0,   192,     0,   177,     0,   178,     0,     0,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,     0,   188,   341,
     189,     0,   190,     0,   191,   176,     0,   192,     0,   177,
       0,   178,     0,     0,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,   342,   189,     0,   190,     0,   191,   176,
       0,   192,     0,   177,     0,   178,     0,     0,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,     0,   188,   343,   189,     0,
     190,     0,   191,   176,     0,   192,     0,   177,     0,   178,
       0,     0,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,     0,
     188,     0,   189,   215,   190,     0,   191,   176,     0,   192,
       0,   177,     0,   178,     0,     0,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,     0,   188,     0,   189,   216,   190,     0,
     191,   176,     0,   192,     0,   177,     0,   178,     0,     0,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,     0,   188,     0,
     189,   264,   190,     0,   191,   176,     0,   192,     0,   177,
       0,   178,     0,     0,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,   214,   188,   176,   189,     0,   190,   177,   191,   178,
       0,   192,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,   219,
     188,   176,   189,     0,   190,   177,   191,   178,     0,   192,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,   220,   188,   176,
     189,     0,   190,   177,   191,   178,     0,   192,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,   234,   188,   176,   189,     0,
     190,   177,   191,   178,     0,   192,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,   244,   188,   176,   189,     0,   190,   177,
     191,   178,     0,   192,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,   245,   188,   176,   189,     0,   190,   177,   191,   178,
       0,   192,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,   246,
     188,   176,   189,     0,   190,   177,   191,   178,     0,   192,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,   247,   188,   176,
     189,     0,   190,   177,   191,   178,     0,   192,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,   248,   188,   176,   189,     0,
     190,   177,   191,   178,     0,   192,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,   251,   188,   176,   189,     0,   190,   177,
     191,   178,     0,   192,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,   253,   188,   176,   189,     0,   190,   177,   191,   178,
       0,   192,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,   256,
     188,   176,   189,     0,   190,   177,   191,   178,     0,   192,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,   257,   188,   176,
     189,     0,   190,   177,   191,   178,     0,   192,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,   260,   188,   176,   189,     0,
     190,   177,   191,   178,     0,   192,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,   265,   188,   176,   189,     0,   190,   177,
     191,   178,     0,   192,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,   313,   188,   176,   189,     0,   190,   177,   191,   178,
       0,   192,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,   318,
     188,   176,   189,     0,   190,   177,   191,   178,     0,   192,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,   321,   188,   176,
     189,     0,   190,   177,   191,   178,     0,   192,     0,   179,
       0,   180,     0,   181,     0,   182,     0,   183,     0,   184,
       0,   185,     0,   186,   187,   323,   188,   176,   189,     0,
     190,   177,   191,   178,     0,   192,     0,   179,     0,   180,
       0,   181,     0,   182,     0,   183,     0,   184,     0,   185,
       0,   186,   187,   332,   188,   176,   189,     0,   190,   177,
     191,   178,     0,   192,     0,   179,     0,   180,     0,   181,
       0,   182,     0,   183,     0,   184,     0,   185,     0,   186,
     187,     0,   188,   176,   189,   310,   190,   177,   191,   178,
       0,   192,     0,   179,     0,   180,     0,   181,     0,   182,
       0,   183,     0,   184,     0,   185,     0,   186,   187,     0,
     188,   176,   189,     0,   190,   177,   191,   178,     0,   192,
       0,   179,     0,   180,     0,   181,     0,   182,     0,   183,
       0,   184,     0,   185,     0,   186,   187,     0,   188,     0,
     189,     0,   190,     0,   191,     0,     0,   192
  };

  const short int
  ExpressionParser::yycheck_[] =
  {
       0,   126,     4,   128,   130,   130,   132,   132,   134,   134,
      95,   137,   137,    18,    99,    15,    16,    17,    20,    19,
      20,    21,    22,    23,    24,    25,    26,    18,    28,    29,
      30,    31,    32,    33,    34,    35,    36,    37,    38,    39,
      40,    41,    42,    43,    44,    45,    46,    47,    48,    49,
      50,    51,    52,    53,    54,    55,    56,    57,    58,    59,
       4,    61,    62,    63,    64,   132,    66,   134,    15,    95,
     137,    22,    16,    99,    24,    19,    20,    96,    97,    18,
      80,    81,    82,    83,    84,    85,    26,    95,     8,    89,
       0,    99,    95,   101,    96,    96,    98,   105,    15,   107,
      96,    97,    18,   111,    26,   113,    24,   115,    79,   117,
     137,   119,    96,   121,    95,   123,    95,   125,   126,    97,
     128,    97,   130,    59,   132,    59,   134,    95,    59,   137,
      93,    99,    89,   101,    88,    -1,    -1,   105,    -1,   107,
      -1,    -1,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    96,   121,    98,   123,    -1,   125,   126,    -1,
     128,    -1,   130,    -1,   132,    -1,   134,    -1,    -1,   137,
      -1,    -1,    -1,    -1,    -1,    -1,   176,   177,   178,   179,
     180,   181,   182,   183,   184,   185,   186,   187,   188,   189,
     190,   191,   192,    -1,    -1,    -1,    -1,    65,   198,    -1,
      68,    69,    70,    71,   125,   126,    -1,   128,   208,   130,
     210,   132,    -1,   134,    -1,    -1,   137,    -1,    -1,   219,
     220,    89,    -1,    91,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,   234,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,   244,   245,   246,   247,   248,    -1,
      -1,   251,    -1,   253,    -1,    -1,   256,   257,    -1,    -1,
     260,    -1,    -1,    -1,    -1,   265,    -1,    -1,    -1,    95,
      -1,    -1,    -1,    99,    -1,   101,    -1,    -1,    -1,   105,
      -1,   107,    -1,   283,   284,   111,   286,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,    -1,   130,    -1,   132,    -1,   134,    -1,
     310,   137,    -1,   313,    -1,    -1,    -1,    -1,   318,    -1,
      -1,   321,    -1,   323,    -1,    -1,   326,     3,    -1,     5,
       6,     7,   332,     9,    10,    11,    12,    13,    14,    -1,
      -1,    17,    -1,    -1,    -1,    21,    -1,    23,    -1,    25,
      -1,    27,    28,    29,    30,    31,    32,    33,    34,    35,
      36,    37,    38,    39,    40,    41,    42,    43,    44,    45,
      46,    47,    48,    49,    50,    51,    52,    53,    54,    55,
      56,    57,    58,    -1,    -1,    61,    62,    63,    64,    65,
      66,    67,    68,    69,    70,    71,    72,    73,    74,    75,
      76,    77,    78,    -1,    80,    81,    82,    83,    84,    85,
      86,    87,    88,    89,    90,    91,    92,    93,    94,    95,
      96,    -1,    98,    -1,    -1,    -1,    -1,    -1,   111,    -1,
     113,    -1,   115,   109,   117,    -1,   119,    -1,   121,    -1,
     123,    -1,   125,   126,    -1,   128,    -1,   130,    -1,   132,
     126,   134,   128,    -1,   137,    -1,    -1,     3,    -1,     5,
       6,     7,   138,     9,    10,    11,    12,    13,    14,    -1,
      -1,    17,    -1,    -1,    -1,    21,    -1,    23,    -1,    25,
      -1,    27,    28,    29,    30,    31,    32,    33,    34,    35,
      36,    37,    38,    39,    40,    41,    42,    43,    44,    45,
      46,    47,    48,    49,    50,    51,    52,    53,    54,    55,
      56,    57,    58,    -1,    -1,    61,    62,    63,    64,    65,
      66,    67,    68,    69,    70,    71,    72,    73,    74,    75,
      76,    77,    78,    -1,    80,    81,    82,    83,    84,    85,
      86,    87,    88,    89,    90,    91,    92,    93,    94,    95,
      96,    -1,    98,    -1,   113,    -1,   115,    -1,   117,    -1,
     119,    -1,   121,   109,   123,    -1,   125,   126,    -1,   128,
      -1,   130,    -1,   132,    -1,   134,    -1,    -1,   137,    -1,
     126,    -1,   128,    -1,    -1,    -1,    -1,     3,    -1,     5,
       6,     7,   138,     9,    10,    11,    12,    13,    14,    -1,
      -1,    17,    -1,    -1,    -1,    21,    -1,    23,    -1,    25,
      -1,    27,    28,    29,    30,    31,    32,    33,    34,    35,
      36,    37,    38,    39,    40,    41,    42,    43,    44,    45,
      46,    47,    48,    49,    50,    51,    52,    53,    54,    55,
      56,    57,    58,    -1,    -1,    61,    62,    63,    64,    65,
      66,    67,    68,    69,    70,    71,    72,    73,    74,    75,
      76,    77,    78,    -1,    80,    81,    82,    83,    84,    85,
      86,    87,    88,    89,    90,    91,    92,    93,    94,    -1,
      96,    -1,    98,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,   109,    -1,    95,    -1,    -1,    -1,    -1,
      -1,   101,    -1,    -1,    -1,   105,    -1,   107,    -1,    -1,
     126,   111,   128,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,   138,   123,    -1,   125,   126,    -1,   128,    95,
     130,    -1,   132,    -1,   134,   101,    -1,   137,    -1,   105,
      -1,   107,    -1,    -1,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,    95,   130,    -1,   132,    -1,   134,   101,
      -1,   137,    -1,   105,    -1,   107,    -1,    -1,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    -1,   128,    95,   130,    -1,
     132,    -1,   134,   101,    -1,   137,    -1,   105,    -1,   107,
      -1,    -1,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    -1,
     128,    95,   130,    -1,   132,    -1,   134,   101,    -1,   137,
      -1,   105,    -1,   107,    -1,    -1,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    -1,   128,    95,   130,    -1,   132,    -1,
     134,   101,    -1,   137,    -1,   105,    -1,   107,    -1,    -1,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    -1,   128,    95,
     130,    -1,   132,    -1,   134,   101,    -1,   137,    -1,   105,
      -1,   107,    -1,    -1,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,    95,   130,    -1,   132,    -1,   134,   101,
      -1,   137,    -1,   105,    -1,   107,    -1,    -1,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    -1,   128,    95,   130,    -1,
     132,    -1,   134,   101,    -1,   137,    -1,   105,    -1,   107,
      -1,    -1,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    -1,
     128,    95,   130,    -1,   132,    -1,   134,   101,    -1,   137,
      -1,   105,    -1,   107,    -1,    -1,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    -1,   128,    95,   130,    -1,   132,    -1,
     134,   101,    -1,   137,    -1,   105,    -1,   107,    -1,    -1,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    -1,   128,    95,
     130,    -1,   132,    -1,   134,   101,    -1,   137,    -1,   105,
      -1,   107,    -1,    -1,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,    95,   130,    -1,   132,    -1,   134,   101,
      -1,   137,    -1,   105,    -1,   107,    -1,    -1,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    -1,   128,    95,   130,    -1,
     132,    -1,   134,   101,    -1,   137,    -1,   105,    -1,   107,
      -1,    -1,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    -1,
     128,    95,   130,    -1,   132,    -1,   134,   101,    -1,   137,
      -1,   105,    -1,   107,    -1,    -1,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    -1,   128,    95,   130,    -1,   132,    -1,
     134,   101,    -1,   137,    -1,   105,    -1,   107,    -1,    -1,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    -1,   128,    95,
     130,    -1,   132,    -1,   134,   101,    -1,   137,    -1,   105,
      -1,   107,    -1,    -1,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,    95,   130,    -1,   132,    -1,   134,   101,
      -1,   137,    -1,   105,    -1,   107,    -1,    -1,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    -1,   128,    95,   130,    -1,
     132,    -1,   134,   101,    -1,   137,    -1,   105,    -1,   107,
      -1,    -1,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    -1,
     128,    95,   130,    -1,   132,    -1,   134,   101,    -1,   137,
      -1,   105,    -1,   107,    -1,    -1,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    -1,   128,    95,   130,    -1,   132,    -1,
     134,   101,    -1,   137,    -1,   105,    -1,   107,    -1,    -1,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    -1,   128,    95,
     130,    -1,   132,    -1,   134,   101,    -1,   137,    -1,   105,
      -1,   107,    -1,    -1,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,    95,   130,    -1,   132,    -1,   134,   101,
      -1,   137,    -1,   105,    -1,   107,    -1,    -1,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    -1,   128,    95,   130,    -1,
     132,    -1,   134,   101,    -1,   137,    -1,   105,    -1,   107,
      -1,    -1,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    -1,
     128,    95,   130,    -1,   132,    -1,   134,   101,    -1,   137,
      -1,   105,    -1,   107,    -1,    -1,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    -1,   128,    95,   130,    -1,   132,    -1,
     134,   101,    -1,   137,    -1,   105,    -1,   107,    -1,    -1,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    -1,   128,    95,
     130,    -1,   132,    -1,   134,   101,    -1,   137,    -1,   105,
      -1,   107,    -1,    -1,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,    95,   130,    -1,   132,    -1,   134,   101,
      -1,   137,    -1,   105,    -1,   107,    -1,    -1,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    -1,   128,    95,   130,    -1,
     132,    -1,   134,   101,    -1,   137,    -1,   105,    -1,   107,
      -1,    -1,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    -1,
     128,    95,   130,    -1,   132,    -1,   134,   101,    -1,   137,
      -1,   105,    -1,   107,    -1,    -1,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    -1,   128,    95,   130,    -1,   132,    -1,
     134,   101,    -1,   137,    -1,   105,    -1,   107,    -1,    -1,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    -1,   128,    95,
     130,    -1,   132,    -1,   134,   101,    -1,   137,    -1,   105,
      -1,   107,    -1,    -1,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,    95,   130,    -1,   132,    -1,   134,   101,
      -1,   137,    -1,   105,    -1,   107,    -1,    -1,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    -1,   128,    95,   130,    -1,
     132,    -1,   134,   101,    -1,   137,    -1,   105,    -1,   107,
      -1,    -1,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    -1,
     128,    95,   130,    -1,   132,    -1,   134,   101,    -1,   137,
      -1,   105,    -1,   107,    -1,    -1,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    -1,   128,    95,   130,    -1,   132,    -1,
     134,   101,    -1,   137,    -1,   105,    -1,   107,    -1,    -1,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    -1,   128,    95,
     130,    -1,   132,    -1,   134,   101,    -1,   137,    -1,   105,
      -1,   107,    -1,    -1,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,    95,   130,    -1,   132,    -1,   134,   101,
      -1,   137,    -1,   105,    -1,   107,    -1,    -1,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    -1,   128,    95,   130,    -1,
     132,    -1,   134,   101,    -1,   137,    -1,   105,    -1,   107,
      -1,    -1,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    -1,
     128,    95,   130,    -1,   132,    -1,   134,   101,    -1,   137,
      -1,   105,    -1,   107,    -1,    -1,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    -1,   128,    95,   130,    -1,   132,    -1,
     134,   101,    -1,   137,    -1,   105,    -1,   107,    -1,    -1,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    -1,   128,    95,
     130,    -1,   132,    -1,   134,   101,    -1,   137,    -1,   105,
      -1,   107,    -1,    -1,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,    95,   130,    -1,   132,    -1,   134,   101,
      -1,   137,    -1,   105,    -1,   107,    -1,    -1,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    -1,   128,    95,   130,    -1,
     132,    -1,   134,   101,    -1,   137,    -1,   105,    -1,   107,
      -1,    -1,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    -1,
     128,    95,   130,    -1,   132,    -1,   134,   101,    -1,   137,
      -1,   105,    -1,   107,    -1,    -1,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    -1,   128,    95,   130,    -1,   132,    -1,
     134,   101,    -1,   137,    -1,   105,    -1,   107,    -1,    -1,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    -1,   128,    95,
     130,    -1,   132,    -1,   134,   101,    -1,   137,    -1,   105,
      -1,   107,    -1,    -1,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,    95,   130,    -1,   132,    -1,   134,   101,
      -1,   137,    -1,   105,    -1,   107,    -1,    -1,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    -1,   128,    95,   130,    -1,
     132,    -1,   134,   101,    -1,   137,    -1,   105,    -1,   107,
      -1,    -1,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    -1,
     128,    -1,   130,    97,   132,    -1,   134,   101,    -1,   137,
      -1,   105,    -1,   107,    -1,    -1,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    -1,   128,    -1,   130,    97,   132,    -1,
     134,   101,    -1,   137,    -1,   105,    -1,   107,    -1,    -1,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    -1,   128,    -1,
     130,    97,   132,    -1,   134,   101,    -1,   137,    -1,   105,
      -1,   107,    -1,    -1,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    99,   128,   101,   130,    -1,   132,   105,   134,   107,
      -1,   137,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    99,
     128,   101,   130,    -1,   132,   105,   134,   107,    -1,   137,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    99,   128,   101,
     130,    -1,   132,   105,   134,   107,    -1,   137,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    99,   128,   101,   130,    -1,
     132,   105,   134,   107,    -1,   137,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    99,   128,   101,   130,    -1,   132,   105,
     134,   107,    -1,   137,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    99,   128,   101,   130,    -1,   132,   105,   134,   107,
      -1,   137,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    99,
     128,   101,   130,    -1,   132,   105,   134,   107,    -1,   137,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    99,   128,   101,
     130,    -1,   132,   105,   134,   107,    -1,   137,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    99,   128,   101,   130,    -1,
     132,   105,   134,   107,    -1,   137,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    99,   128,   101,   130,    -1,   132,   105,
     134,   107,    -1,   137,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    99,   128,   101,   130,    -1,   132,   105,   134,   107,
      -1,   137,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    99,
     128,   101,   130,    -1,   132,   105,   134,   107,    -1,   137,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    99,   128,   101,
     130,    -1,   132,   105,   134,   107,    -1,   137,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    99,   128,   101,   130,    -1,
     132,   105,   134,   107,    -1,   137,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    99,   128,   101,   130,    -1,   132,   105,
     134,   107,    -1,   137,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    99,   128,   101,   130,    -1,   132,   105,   134,   107,
      -1,   137,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    99,
     128,   101,   130,    -1,   132,   105,   134,   107,    -1,   137,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    99,   128,   101,
     130,    -1,   132,   105,   134,   107,    -1,   137,    -1,   111,
      -1,   113,    -1,   115,    -1,   117,    -1,   119,    -1,   121,
      -1,   123,    -1,   125,   126,    99,   128,   101,   130,    -1,
     132,   105,   134,   107,    -1,   137,    -1,   111,    -1,   113,
      -1,   115,    -1,   117,    -1,   119,    -1,   121,    -1,   123,
      -1,   125,   126,    99,   128,   101,   130,    -1,   132,   105,
     134,   107,    -1,   137,    -1,   111,    -1,   113,    -1,   115,
      -1,   117,    -1,   119,    -1,   121,    -1,   123,    -1,   125,
     126,    -1,   128,   101,   130,   103,   132,   105,   134,   107,
      -1,   137,    -1,   111,    -1,   113,    -1,   115,    -1,   117,
      -1,   119,    -1,   121,    -1,   123,    -1,   125,   126,    -1,
     128,   101,   130,    -1,   132,   105,   134,   107,    -1,   137,
      -1,   111,    -1,   113,    -1,   115,    -1,   117,    -1,   119,
      -1,   121,    -1,   123,    -1,   125,   126,    -1,   128,    -1,
     130,    -1,   132,    -1,   134,    -1,    -1,   137
  };

  const unsigned char
  ExpressionParser::yystos_[] =
  {
       0,     3,     5,     6,     7,     9,    10,    11,    12,    13,
      14,    17,    21,    23,    25,    27,    28,    29,    30,    31,
      32,    33,    34,    35,    36,    37,    38,    39,    40,    41,
      42,    43,    44,    45,    46,    47,    48,    49,    50,    51,
      52,    53,    54,    55,    56,    57,    58,    61,    62,    63,
      64,    65,    66,    67,    68,    69,    70,    71,    72,    73,
      74,    75,    76,    77,    78,    80,    81,    82,    83,    84,
      85,    86,    87,    88,    89,    90,    91,    92,    93,    94,
      96,    98,   109,   126,   128,   138,   140,   141,   149,   153,
     154,   155,     4,    16,    19,    20,    96,    98,   150,   151,
     152,   141,   145,   147,    18,    18,    15,   144,    18,    22,
      24,   143,    26,   142,   141,   141,   141,     8,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,    95,   141,
     141,   141,   141,   145,   141,   145,   145,   145,   145,   141,
     141,   141,   141,   141,   141,     0,   101,   105,   107,   111,
     113,   115,   117,   119,   121,   123,   125,   126,   128,   130,
     132,   134,   137,   150,   141,   145,   146,   147,    96,   148,
     145,   144,    18,   151,   152,   151,   152,    95,    99,    95,
      99,    15,    24,    26,    99,    97,    97,    79,    95,    99,
      99,    95,    95,    95,    95,    95,    95,    95,    95,    95,
      95,    95,    95,    95,    99,    95,    95,    95,    95,    95,
      95,    95,    95,    95,    99,    99,    99,    99,    99,    95,
      95,    99,    95,    99,    95,    95,    99,    99,    95,    95,
      99,    95,    95,    95,    97,    99,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,    99,    99,   141,    96,    95,    95,    97,
      97,   141,   141,    59,    59,    59,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     103,    95,    95,    99,   141,    95,    95,    95,    99,    95,
      95,    99,    95,    99,    95,    95,    99,    95,    95,    95,
     141,   141,    99,   141,   141,   141,   141,    95,   141,    95,
      95,    95,    95,    95
  };

  const unsigned char
  ExpressionParser::yyr1_[] =
  {
       0,   139,   140,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   141,   141,   141,
     141,   141,   141,   141,   141,   141,   141,   142,   142,   143,
     143,   144,   144,   145,   145,   146,   146,   147,   147,   148,
     148,   149,   149,   150,   150,   150,   150,   151,   151,   151,
     152,   152,   152,   153,   153,   154,   154,   155,   155
  };

  const unsigned char
  ExpressionParser::yyr2_[] =
  {
       0,     2,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     3,     3,     3,     3,     3,     5,
       3,     5,     5,     3,     3,     2,     2,     3,     5,     2,
       2,     2,     2,     2,     2,     2,     1,     1,     5,     5,
       2,     3,     3,     3,     3,     3,     3,     1,     3,     3,
       3,     3,     3,     3,     3,     3,     5,     3,     3,     3,
       3,     3,     3,     3,     3,     3,     3,     3,     3,     3,
       5,     7,     3,     3,     1,     3,     2,     2,     2,     2,
       2,     3,     3,     5,     7,     7,     5,     5,     2,     2,
       2,     2,     2,     5,     7,     3,     3,     3,     3,     3,
       3,     3,     3,     3,     2,     1,     3,     1,     2,     1,
       2,     1,     2,     2,     2,     3,     3,     3,     3,     5,
       6,     2,     2,     2,     2,     1,     1,     1,     3,     3,
       1,     3,     3,     3,     4,     3,     4,     3,     4
  };


#if XYCEEXPRESSIONDEBUG
  // YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
  // First, the terminals, then, starting at \a yyntokens_, nonterminals.
  const char*
  const ExpressionParser::yytname_[] =
  {
  "$end", "error", "$undefined", "\"polysize\"", "\"polycoef\"",
  "\"num\"", "\"imag_num\"", "\"word\"", "\"filename\"", "\"function\"",
  "\"lead\"", "\"onoise\"", "\"inoise\"", "\"power\"", "\"voltage\"",
  "\"voltagenode\"", "\"poly_voltage\"", "\"current\"",
  "\"currentdevice\"", "\"poly_current\"", "\"poly_word\"",
  "\"internal_variable\"", "\"internal_variable_device\"", "\"noise\"",
  "\"noise_device_variable\"", "\"rfparam\"", "\"rf_param_arg\"",
  "\"table\"", "\"table2\"", "\"table3\"", "\"tablefile\"", "\"sqrt\"",
  "\"max\"", "\"min\"", "\"phase\"", "\"real\"", "\"imag\"", "\"db\"",
  "\"exp\"", "\"exp_const\"", "\"sin\"", "\"cos\"", "\"m\"", "\"abs\"",
  "\"acos\"", "\"acosh\"", "\"asin\"", "\"asinh\"", "\"atan2\"",
  "\"atan\"", "\"atanh\"", "\"cosh\"", "\"ln\"", "\"log\"", "\"log10\"",
  "\"sinh\"", "\"tan\"", "\"tanh\"", "\"if\"", "\"equals\"",
  "\"semicolon\"", "\"aunif\"", "\"unif\"", "\"agauss\"", "\"fmod\"",
  "\"nint\"", "\"ceil\"", "\"gauss\"", "\"ddt\"", "\"ddx\"", "\"floor\"",
  "\"int\"", "\"limit\"", "\"pwrs\"", "\"rand\"", "\"sdt\"", "\"sgn\"",
  "\"sign\"", "\"stp\"", "\"tablefile_end\"", "\"schedule\"", "\"uramp\"",
  "\"bad_poly\"", "\"spice_pulse\"", "\"spice_sin\"", "\"spice_exp\"",
  "\"spice_sffm\"", "\"dt\"", "\"time\"", "\"temp\"", "\"vt\"", "\"freq\"",
  "\"gmin\"", "\"pi\"", "\"CtoK\"", "\"rightparen\"", "\"leftparen\"",
  "\"rightcurlybrace\"", "\"leftcurlybrace\"", "TOK_COMMA", "\",\"",
  "TOK_QUESTION_MARK", "\"?\"", "TOK_COLON", "\":\"", "TOK_OR", "\"||\"",
  "TOK_AND", "\"&&\"", "TOK_NOT", "\"~\"", "TOK_CARET", "\"^\"", "TOK_EQ",
  "\"==\"", "TOK_NE", "\"!=\"", "TOK_LE", "\"<=\"", "TOK_LT", "\"<\"",
  "TOK_GE", "\">=\"", "TOK_GT", "\">\"", "TOK_INVALID_OP", "TOK_MINUS",
  "\"-\"", "TOK_PLUS", "\"+\"", "TOK_MOD", "\"%\"", "TOK_MULTIPLY",
  "\"*\"", "TOK_DIVIDE", "\"/\"", "NEG", "TOK_POW", "TOK_POWFUNC",
  "$accept", "expression", "exp", "nonempty_rfparam_arg_list",
  "nonempty_noise_device_list", "nonempty_voltagenodelist",
  "nonempty_func_arglist", "nonempty_func_arglist2", "two_or_more_arglist",
  "nonempty_arg_pairs", "polypair", "polyarg", "paren_polycoef",
  "paren_polyword", "table_threeOrFourArgs", "table2_threeOrFourArgs",
  "table3_threeOrFourArgs", YY_NULLPTR
  };


  const unsigned short int
  ExpressionParser::yyrline_[] =
  {
       0,   780,   780,   795,   799,   804,   809,   814,   821,   828,
     835,   842,   849,   857,   865,   875,   885,   895,   905,   909,
     914,   924,   934,   947,   951,   955,   962,   969,   982,   996,
    1024,  1030,  1036,  1118,  1136,  1189,  1209,  1216,  1223,  1227,
    1231,  1248,  1253,  1257,  1261,  1268,  1281,  1294,  1299,  1312,
    1325,  1338,  1351,  1364,  1377,  1390,  1403,  1407,  1420,  1433,
    1446,  1459,  1482,  1492,  1502,  1512,  1522,  1526,  1530,  1534,
    1538,  1544,  1548,  1553,  1557,  1565,  1575,  1586,  1597,  1608,
    1635,  1643,  1653,  1663,  1667,  1674,  1681,  1688,  1695,  1705,
    1714,  1723,  1732,  1739,  1743,  1747,  1752,  1757,  1762,  1767,
    1772,  1777,  1781,  1785,  1796,  1801,  1812,  1825,  1826,  1828,
    1829,  1831,  1832,  1834,  1835,  1837,  1838,  1840,  1841,  1843,
    1844,  1847,  1852,  1855,  1861,  1867,  1872,  1877,  1881,  1885,
    1891,  1895,  1899,  1919,  1926,  1933,  1940,  1947,  1954
  };

  // Print the state stack on the debug stream.
  void
  ExpressionParser::yystack_print_ ()
  {
    *yycdebug_ << "Stack now";
    for (stack_type::const_iterator
           i = yystack_.begin (),
           i_end = yystack_.end ();
         i != i_end; ++i)
      *yycdebug_ << ' ' << i->state;
    *yycdebug_ << std::endl;
  }

  // Report on the debug stream that the rule \a yyrule is going to be reduced.
  void
  ExpressionParser::yy_reduce_print_ (int yyrule)
  {
    unsigned int yylno = yyrline_[yyrule];
    int yynrhs = yyr2_[yyrule];
    // Print the symbols being reduced, and their result.
    *yycdebug_ << "Reducing stack by rule " << yyrule - 1
               << " (line " << yylno << "):" << std::endl;
    // The symbols being reduced.
    for (int yyi = 0; yyi < yynrhs; yyi++)
      YY_SYMBOL_PRINT ("   $" << yyi + 1 << " =",
                       yystack_[(yynrhs) - (yyi + 1)]);
  }
#endif // XYCEEXPRESSIONDEBUG

  // Symbol number corresponding to token number t.
  inline
  ExpressionParser::token_number_type
  ExpressionParser::yytranslate_ (int t)
  {
    static
    const token_number_type
    translate_table[] =
    {
     0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,    68,    69,    70,    71,    72,    73,    74,
      75,    76,    77,    78,    79,    80,    81,    82,    83,    84,
      85,    86,    87,    88,    89,    90,    91,    92,    93,    94,
      95,    96,    97,    98,    99,   100,   101,   102,   103,   104,
     105,   106,   107,   108,   109,   110,   111,   112,   113,   114,
     115,   116,   117,   118,   119,   120,   121,   122,   123,   124,
     125,   126,   127,   128,   129,   130,   131,   132,   133,   134,
     135,   136,   137,   138
    };
    const unsigned int user_token_number_max_ = 393;
    const token_number_type undef_token_ = 2;

    if (static_cast<int>(t) <= yyeof_)
      return yyeof_;
    else if (static_cast<unsigned int> (t) <= user_token_number_max_)
      return translate_table[t];
    else
      return undef_token_;
  }


} // XyceExpression
#line 5301 "/builddir/build/BUILD/xyce/build/src/UtilityPKG/ExpressionSrc/ExpressionParser.cxx" // lalr1.cc:1167
#line 1962 "UtilityPKG/ExpressionSrc/ExpressionParser.yxx" // lalr1.cc:1168


int XyceExpressionlex(
    XyceExpression::ExpressionParser::semantic_type *lvalp, 
    XyceExpression::location *locp,
    Xyce::Util::ExpressionLexer *theLexer)
{
  return(theLexer->getToken(lvalp,locp));
}

void
XyceExpression::ExpressionParser::error(
  const XyceExpression::ExpressionParser::location_type & l,
  const std::string &                               message)
{
  Xyce::Report::UserError()
   << message << " in expression " << newExp.getExpressionString() << std::endl;
}
